#

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data_1 = {
    "1960s in Papua New Guinean sport": "x",
    "1962 in Papua New Guinean sport": "x",
    "1969 in Papua New Guinean sport": "x",
    "1970s in Papua New Guinean sport": "x",
    "1975 in Papua New Guinean sport": "x",
    "1976 in Papua New Guinean sport": "x",
    "1980s in Papua New Guinean sport": "x",
    "1982 in Papua New Guinean sport": "x",
    "1983 in Papua New Guinean sport": "x",
    "1984 in Papua New Guinean sport": "x",
    "1985 in Papua New Guinean sport": "x",
    "1986 in Papua New Guinean sport": "x",
    "1988 in Papua New Guinean rugby league": "x",
    "1988 in Papua New Guinean sport": "x",
    "1989 in Papua New Guinean sport": "x",
    "1990 in Papua New Guinean rugby league": "x",
    "1990 in Papua New Guinean sport": "x",
    "1990s in Papua New Guinean sport": "x",
    "1990s in Papua New Guinean television": "x",
    "1990s Papua New Guinean television series": "x",
    "1991 in Papua New Guinean rugby league": "x",
    "1991 in Papua New Guinean sport": "x",
    "1992 in Papua New Guinean rugby league": "x",
    "1992 in Papua New Guinean sport": "x",
    "1994 in Papua New Guinean rugby league": "x",
    "1994 in Papua New Guinean sport": "x",
    "1996 in Papua New Guinean rugby league": "x",
    "1996 in Papua New Guinean sport": "x",
    "1997 in Papua New Guinean sport": "x",
    "2000 in Papua New Guinean sport": "x",
    "2000s in Papua New Guinean sport": "x",
    "2001 in Papua New Guinean rugby league": "x",
    "2001 in Papua New Guinean soccer": "x",
    "2001 in Papua New Guinean sport": "x",
    "2003 in Papua New Guinean sport": "x",
    "2004 in Papua New Guinean sport": "x",
    "2005 in Papua New Guinean sport": "x",
    "2006 in Papua New Guinean sport": "x",
    "2007 in Papua New Guinean sport": "x",
    "2008 in Papua New Guinean sport": "x",
    "2009 in Papua New Guinean sport": "x",
    "2010 in Papua New Guinean sport": "x",
    "2010s in Papua New Guinean sport": "x",
    "2011 in Papua New Guinean sport": "x",
    "2011–2012 Papua New Guinean constitutional crisis": "x",
    "2012 in Papua New Guinean sport": "x",
    "2013 in Papua New Guinean sport": "x",
    "2014 in Papua New Guinean sport": "x",
    "2015 in Papua New Guinean sport": "x",
    "2016 in Papua New Guinean cricket": "x",
    "2016 in Papua New Guinean sport": "x",
    "2017 in Papua New Guinean cricket": "x",
    "2017 in Papua New Guinean sport": "x",
    "2018 in Papua New Guinean sport": "x",
    "2019 in Papua New Guinean cricket": "x",
    "2019 in Papua New Guinean sport": "x",
    "2020 in Papua New Guinean sport": "x",
    "2020s in Papua New Guinean cricket": "x",
    "2020s in Papua New Guinean sport": "x",
    "2021 in Papua New Guinean cricket": "x",
    "2021 in Papua New Guinean sport": "x",
    "2022 in Papua New Guinean cricket": "x",
    "2022 in Papua New Guinean sport": "x",
    "2023 in Papua New Guinean cricket": "x",
    "2023 in Papua New Guinean sport": "x",
    "2024 in Papua New Guinean cricket": "x",
    "2024 in Papua New Guinean sport": "x",
    "2025 in Papua New Guinean sport": "x",
    "20th century in Papua New Guinean television": "x",
    "20th-century Papua New Guinean businesspeople": "x",
    "20th-century Papua New Guinean painters": "x",
    "20th-century Papua New Guinean people": "x",
    "20th-century Papua New Guinean politicians": "x",
    "20th-century Papua New Guinean sportsmen": "x",
    "20th-century Papua New Guinean sportspeople": "x",
    "20th-century Papua New Guinean sportswomen": "x",
    "20th-century Papua New Guinean television series": "x",
    "21st-century Papua New Guinean people": "x",
    "21st-century Papua New Guinean politicians": "x",
    "21st-century Papua New Guinean sportsmen": "x",
    "21st-century Papua New Guinean sportspeople": "x",
    "21st-century Papua New Guinean sportswomen": "x",
    "Albums by Papua New Guinean artists": "x",
    "Albums by Papua New Guinean artists by genre": "x",
    "Assassinated Papua New Guinean politicians": "x",
    "Australian people of Papua New Guinean descent": "x",
    "British people of Papua New Guinean descent": "x",
    "Fijian people of Papua New Guinean descent": "x",
    "Hip-hop albums by Papua New Guinean artists": "x",
    "Japanese people of Papua New Guinean descent": "x",
    "Lists of Papua New Guinean ambassadors": "x",
    "Lists of Papua New Guinean cricketers": "x",
    "Lists of Papua New Guinean people": "x",
    "Lists of Papua New Guinean sportspeople": "x",
    "New Zealand people of Papua New Guinean descent": "x",
    "Papua New Guinean academics": "x",
    "Papua New Guinean accountants": "x",
    "Papua New Guinean activists": "x",
    "Papua New Guinean actor-politicians": "x",
    "Papua New Guinean actors": "x",
    "Papua New Guinean Anglicans": "x",
    "Papua New Guinean anti-corruption activists": "x",
    "Papua New Guinean anti-war activists": "x",
    "Papua New Guinean archaeologists": "x",
    "Papua New Guinean artists": "x",
    "Papua New Guinean athletes": "x",
    "Papua New Guinean aviators": "x",
    "Papua New Guinean award winners": "x",
    "Papua New Guinean awards": "x",
    "Papua New Guinean badminton players": "x",
    "Papua New Guinean bankers": "x",
    "Papua New Guinean basketball players": "x",
    "Papua New Guinean beatified people": "x",
    "Papua New Guinean biologists": "x",
    "Papua New Guinean bishops": "x",
    "Papua New Guinean bowling players": "x",
    "Papua New Guinean bowls players": "x",
    "Papua New Guinean boxers": "x",
    "Papua New Guinean broadcasters": "x",
    "Papua New Guinean businesspeople": "x",
    "Papua New Guinean businesswomen": "x",
    "Papua New Guinean cardinals": "x",
    "Papua New Guinean chess players": "x",
    "Papua New Guinean Christian missionaries": "x",
    "Papua New Guinean Christians": "x",
    "Papua New Guinean civil servants": "x",
    "Papua New Guinean clergy": "x",
    "Papua New Guinean climate activists": "x",
    "Papua New Guinean Commanders of the Order of the British Empire": "x",
    "Papua New Guinean competitors by sports event": "x",
    "Papua New Guinean cricket captains": "x",
    "Papua New Guinean cricket coaches": "x",
    "Papua New Guinean cricket people": "x",
    "Papua New Guinean cricket tours abroad": "x",
    "Papua New Guinean cricket tours of Australia": "x",
    "Papua New Guinean cricket tours of Hong Kong": "x",
    "Papua New Guinean cricket tours of the United Arab Emirates": "x",
    "Papua New Guinean cricket umpires": "x",
    "Papua New Guinean cricketers": "x",
    "Papua New Guinean criminals": "x",
    "Papua New Guinean cuisine": "x",
    "Papua New Guinean curators": "x",
    "Papua New Guinean dancers": "x",
    "Papua New Guinean decathletes": "x",
    "Papua New Guinean deities": "x",
    "Papua New Guinean designers": "x",
    "Papua New Guinean diaspora": "x",
    "Papua New Guinean diplomats": "x",
    "Papua New Guinean dramatists and playwrights": "x",
    "Papua New Guinean economists": "x",
    "Papua New Guinean editors": "x",
    "Papua New Guinean educators": "x",
    "Papua New Guinean emigrants": "x",
    "Papua New Guinean emigrants to Australia": "x",
    "Papua New Guinean emigrants to Canada": "x",
    "Papua New Guinean emigrants to Japan": "x",
    "Papua New Guinean emigrants to New Zealand": "x",
    "Papua New Guinean environmentalists": "x",
    "Papua New Guinean evangelicals": "x",
    "Papua New Guinean expatriate judges": "x",
    "Papua New Guinean expatriate men's soccer players": "x",
    "Papua New Guinean expatriate rugby league players": "x",
    "Papua New Guinean expatriate rugby league players in Australia": "x",
    "Papua New Guinean expatriate rugby league players in England": "x",
    "Papua New Guinean expatriate rugby union players": "x",
    "Papua New Guinean expatriate soccer players": "x",
    "Papua New Guinean expatriate sportspeople": "x",
    "Papua New Guinean expatriate sportspeople by country of residence": "x",
    "Papua New Guinean expatriate sportspeople in Australia": "x",
    "Papua New Guinean expatriate sportspeople in England": "x",
    "Papua New Guinean expatriate sportspeople in Finland": "x",
    "Papua New Guinean expatriate sportspeople in France": "x",
    "Papua New Guinean expatriate sportspeople in Malaysia": "x",
    "Papua New Guinean expatriate sportspeople in New Zealand": "x",
    "Papua New Guinean expatriate sportspeople in the Netherlands": "x",
    "Papua New Guinean expatriate sportspeople in the Philippines": "x",
    "Papua New Guinean expatriate sportspeople in the Solomon Islands": "x",
    "Papua New Guinean expatriate sportspeople in the United Kingdom": "x",
    "Papua New Guinean expatriate sportspeople in the United States": "x",
    "Papua New Guinean expatriate sportspeople in Wales": "x",
    "Papua New Guinean expatriate women's soccer players": "x",
    "Papua New Guinean expatriates": "x",
    "Papua New Guinean expatriates in Australia": "x",
    "Papua New Guinean expatriates in Belgium": "x",
    "Papua New Guinean expatriates in England": "x",
    "Papua New Guinean expatriates in Fiji": "x",
    "Papua New Guinean expatriates in Finland": "x",
    "Papua New Guinean expatriates in France": "x",
    "Papua New Guinean expatriates in New Zealand": "x",
    "Papua New Guinean expatriates in the Netherlands": "x",
    "Papua New Guinean expatriates in the Solomon Islands": "x",
    "Papua New Guinean expatriates in the United Kingdom": "x",
    "Papua New Guinean expatriates in the United States": "x",
    "Papua New Guinean expatriates in Wales": "x",
    "Papua New Guinean farmers": "x",
    "Papua New Guinean fashion designers": "x",
    "Papua New Guinean female bowls players": "x",
    "Papua New Guinean female freestyle swimmers": "x",
    "Papua New Guinean female martial artists": "x",
    "Papua New Guinean female rugby league players": "x",
    "Papua New Guinean female rugby union players": "x",
    "Papua New Guinean female sailors (sport)": "x",
    "Papua New Guinean female swimmers": "x",
    "Papua New Guinean female taekwondo practitioners": "x",
    "Papua New Guinean female tennis players": "x",
    "Papua New Guinean female weightlifters": "x",
    "Papua New Guinean football managers": "x",
    "Papua New Guinean gospel singers": "x",
    "Papua New Guinean heptathletes": "x",
    "Papua New Guinean high jumpers": "x",
    "Papua New Guinean historians": "x",
    "Papua New Guinean hurdlers": "x",
    "Papua New Guinean javelin throwers": "x",
    "Papua New Guinean journalists": "x",
    "Papua New Guinean judges": "x",
    "Papua New Guinean judges on the courts of Fiji": "x",
    "Papua New Guinean judoka": "x",
    "Papua New Guinean knights": "x",
    "Papua New Guinean Knights Bachelor": "x",
    "Papua New Guinean Knights Commander of the Order of St Michael and St George": "x",
    "Papua New Guinean Knights Commander of the Order of the British Empire": "x",
    "Papua New Guinean lawyers": "x",
    "Papua New Guinean librarians": "x",
    "Papua New Guinean literature": "x",
    "Papua New Guinean long jumpers": "x",
    "Papua New Guinean long-distance runners": "x",
    "Papua New Guinean male bowls players": "x",
    "Papua New Guinean male boxers": "x",
    "Papua New Guinean male judoka": "x",
    "Papua New Guinean male martial artists": "x",
    "Papua New Guinean male sailors (sport)": "x",
    "Papua New Guinean male sport shooters": "x",
    "Papua New Guinean male swimmers": "x",
    "Papua New Guinean male taekwondo practitioners": "x",
    "Papua New Guinean male weightlifters": "x",
    "Papua New Guinean marathon runners": "x",
    "Papua New Guinean martial artists": "x",
    "Papua New Guinean mass media people": "x",
    "Papua New Guinean media personalities": "x",
    "Papua New Guinean members of the Privy Council of the United Kingdom": "x",
    "Papua New Guinean men": "x",
    "Papua New Guinean men athletes": "x",
    "Papua New Guinean men hurdlers": "x",
    "Papua New Guinean men javelin throwers": "x",
    "Papua New Guinean men long-distance runners": "x",
    "Papua New Guinean men marathon runners": "x",
    "Papua New Guinean men middle-distance runners": "x",
    "Papua New Guinean men sprinters": "x",
    "Papua New Guinean men's basketball players": "x",
    "Papua New Guinean men's soccer players": "x",
    "Papua New Guinean middle-distance runners": "x",
    "Papua New Guinean military personnel": "x",
    "Papua New Guinean miners": "x",
    "Papua New Guinean missionaries": "x",
    "Papua New Guinean murder victims": "x",
    "Papua New Guinean murderers": "x",
    "Papua New Guinean musical instruments": "x",
    "Papua New Guinean musicians": "x",
    "Papua New Guinean mythology": "x",
    "Papua New Guinean netball players": "x",
    "Papua New Guinean newspaper editors": "x",
    "Papua New Guinean novelists": "x",
    "Papua New Guinean officials of the United Nations": "x",
    "Papua New Guinean One Day International cricket umpires": "x",
    "Papua New Guinean painters": "x",
    "Papua New Guinean para-badminton players": "x",
    "Papua New Guinean people": "x",
    "Papua New Guinean people by descent": "x",
    "Papua New Guinean people by occupation": "x",
    "Papua New Guinean people by political orientation": "x",
    "Papua New Guinean people by province": "x",
    "Papua New Guinean people by region": "x",
    "Papua New Guinean people by religion": "x",
    "Papua New Guinean people in sports": "x",
    "Papua New Guinean people of Asian descent": "x",
    "Papua New Guinean people of Australian descent": "x",
    "Papua New Guinean people of Austrian descent": "x",
    "Papua New Guinean people of British descent": "x",
    "Papua New Guinean people of Chinese descent": "x",
    "Papua New Guinean people of Cypriot descent": "x",
    "Papua New Guinean people of English descent": "x",
    "Papua New Guinean people of European descent": "x",
    "Papua New Guinean people of Filipino descent": "x",
    "Papua New Guinean people of German descent": "x",
    "Papua New Guinean people of Greek Cypriot descent": "x",
    "Papua New Guinean people of Greek descent": "x",
    "Papua New Guinean people of Irish descent": "x",
    "Papua New Guinean people of Japanese descent": "x",
    "Papua New Guinean people of Lithuanian descent": "x",
    "Papua New Guinean people of Malaysian descent": "x",
    "Papua New Guinean people of Oceanian descent": "x",
    "Papua New Guinean people of Sri Lankan descent": "x",
    "Papua New Guinean people of Tongan descent": "x",
    "Papua New Guinean people of Welsh descent": "x",
    "Papua New Guinean people with disabilities": "x",
    "Papua New Guinean philosophers": "x",
    "Papua New Guinean physicians": "x",
    "Papua New Guinean players of Australian rules football": "x",
    "Papua New Guinean poets": "x",
    "Papua New Guinean police officers": "x",
    "Papua New Guinean political people": "x",
    "Papua New Guinean politicians": "x",
    "Papua New Guinean politicians by party": "x",
    "Papua New Guinean politicians of Chinese descent": "x",
    "Papua New Guinean prisoners and detainees": "x",
    "Papua New Guinean prisoners sentenced to death": "x",
    "Papua New Guinean Protestant missionaries": "x",
    "Papua New Guinean Protestants": "x",
    "Papua New Guinean radio people": "x",
    "Papua New Guinean radio personalities": "x",
    "Papua New Guinean recipients of British honours": "x",
    "Papua New Guinean recipients of British titles": "x",
    "Papua New Guinean recipients of the British Empire Medal": "x",
    "Papua New Guinean records": "x",
    "Papua New Guinean referees and umpires": "x",
    "Papua New Guinean religious leaders": "x",
    "Papua New Guinean Roman Catholic archbishops": "x",
    "Papua New Guinean Roman Catholic bishops": "x",
    "Papua New Guinean Roman Catholic priests": "x",
    "Papua New Guinean Roman Catholics": "x",
    "Papua New Guinean rugby league administrators": "x",
    "Papua New Guinean rugby league coaches": "x",
    "Papua New Guinean rugby league players": "x",
    "Papua New Guinean rugby league players by province": "x",
    "Papua New Guinean rugby league seasons": "x",
    "Papua New Guinean rugby union players": "x",
    "Papua New Guinean runners": "x",
    "Papua New Guinean sailors (sport)": "x",
    "Papua New Guinean schoolteachers": "x",
    "Papua New Guinean scientists": "x",
    "Papua New Guinean Seventh-day Adventists": "x",
    "Papua New Guinean shot putters": "x",
    "Papua New Guinean singers": "x",
    "Papua New Guinean soccer logos": "x",
    "Papua New Guinean soccer players": "x",
    "Papua New Guinean soccer referees": "x",
    "Papua New Guinean social democrats": "x",
    "Papua New Guinean social workers": "x",
    "Papua New Guinean sport by decade": "x",
    "Papua New Guinean sport by year": "x",
    "Papua New Guinean sport shooters": "x",
    "Papua New Guinean sports coaches": "x",
    "Papua New Guinean sportsmen": "x",
    "Papua New Guinean sportspeople": "x",
    "Papua New Guinean sportspeople by province": "x",
    "Papua New Guinean sportspeople by sport": "x",
    "Papua New Guinean sportsperson-politicians": "x",
    "Papua New Guinean sportswomen": "x",
    "Papua New Guinean sprinters": "x",
    "Papua New Guinean steeplechase runners": "x",
    "Papua New Guinean swimmers": "x",
    "Papua New Guinean taekwondo practitioners": "x",
    "Papua New Guinean television series": "x",
    "Papua New Guinean television series by century": "x",
    "Papua New Guinean television series by decade": "x",
    "Papua New Guinean television shows": "x",
    "Papua New Guinean tennis players": "x",
    "Papua New Guinean theatre people": "x",
    "Papua New Guinean trade unionists": "x",
    "Papua New Guinean triple jumpers": "x",
    "Papua New Guinean Twenty20 International cricket umpires": "x",
    "Papua New Guinean victims of crime": "x",
    "Papua New Guinean weightlifters": "x",
    "Papua New Guinean Wikipedians": "x",
    "Papua New Guinean women": "x",
    "Papua New Guinean women academics": "x",
    "Papua New Guinean women activists": "x",
    "Papua New Guinean women artists": "x",
    "Papua New Guinean women athletes": "x",
    "Papua New Guinean women by occupation": "x",
    "Papua New Guinean women civil servants": "x",
    "Papua New Guinean women cricketers": "x",
    "Papua New Guinean women diplomats": "x",
    "Papua New Guinean women environmentalists": "x",
    "Papua New Guinean women fashion designers": "x",
    "Papua New Guinean women hurdlers": "x",
    "Papua New Guinean women in politics": "x",
    "Papua New Guinean women javelin throwers": "x",
    "Papua New Guinean women lawyers": "x",
    "Papua New Guinean women long-distance runners": "x",
    "Papua New Guinean women middle-distance runners": "x",
    "Papua New Guinean women runners": "x",
    "Papua New Guinean women scientists": "x",
    "Papua New Guinean women shot putters": "x",
    "Papua New Guinean women sprinters": "x",
    "Papua New Guinean women writers": "x",
    "Papua New Guinean women's basketball players": "x",
    "Papua New Guinean women's rights activists": "x",
    "Papua New Guinean women's soccer players": "x",
    "Papua New Guinean writers": "x",
    "People of Papua New Guinean descent": "x",
    "Reggae albums by Papua New Guinean artists": "x",
    "Seasons in Papua New Guinean soccer": "x",
    "Seasons in Papua New Guinean sport": "x",
    "Surnames of Papua New Guinean origin": "x",
    "Works by Papua New Guinean people": "x",
}
to_test = [
    ("test_papua_new_guinean_1", data_1),
]

test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=True)



#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data0 = {}

data_1 = {
    "People from the Spanish Netherlands executed for witchcraft": "أشخاص من هولندا الإسبانية أعدموا بتهمة السحر",
    "French people executed by guillotine during the French Revolution": "فرنسيون أعدموا بالمقصلة خلال الثورة الفرنسية",
    "People executed by Kingdom of England by burning": "أشخاص أعدموا من قبل مملكة إنجلترا بالحرق",
    "People executed by the House of Lancaster": "أشخاص أعدموا من قبل الهاوس في لانكستر",
    "People executed by the House of York": "أشخاص أعدموا من قبل الهاوس في يورك",
    "People executed by the International Military Tribunal in Nuremberg": "أشخاص أعدموا من قبل المحكمة العسكرية الدولية في نورنبيرغ",
    "People executed by the Jin dynasty (266–420) by decapitation": "أشخاص أعدموا من قبل أسرة جين (266–420) بقطع الرأس",
    "People executed by the Kingdom of England by burning": "أشخاص أعدموا من قبل مملكة إنجلترا بالحرق",
    "People executed by the Kingdom of England by decapitation": "أشخاص أعدموا من قبل مملكة إنجلترا بقطع الرأس",
    "People executed by the Kingdom of England by firearm": "أشخاص أعدموا من قبل مملكة إنجلترا بسلاح ناري",
    "People executed by the Kingdom of England by hanging": "أشخاص أعدموا من قبل مملكة إنجلترا بالشنق",
    "People executed by the Kingdom of Ireland by hanging": "أشخاص أعدموا من قبل مملكة أيرلندا بالشنق",
    "People executed by the Kingdom of Scotland by burning": "أشخاص أعدموا من قبل مملكة إسكتلندا بالحرق",
    "People executed by the Kingdom of Scotland by decapitation": "أشخاص أعدموا من قبل مملكة إسكتلندا بقطع الرأس",
    "People executed by the Kingdom of Scotland by hanging": "أشخاص أعدموا من قبل مملكة إسكتلندا بالشنق",
    "National youth sports teams of the United States": "منتخبات رياضية وطنية شبابية في الولايات المتحدة",
    "Women's national sports teams of the United States": "منتخبات رياضية وطنية نسائية في الولايات المتحدة",
    "Women from Dutch Caribbean": "المرأة من كاريبيون هولنديون",
    "Women from Kingdom of Prussia": "المرأة من مملكة بروسيا",
    "Women from Kingdom of Travancore": "المرأة من مملكة ترافنكور",
    "Women from Overseas France": "المرأة من مقاطعات وأقاليم ما وراء البحار الفرنسية",
    "2010s crimes in Europe by city": "جرائم عقد 2010 في أوروبا حسب المدينة",
    "Jews and Judaism in Kingdom of Jerusalem": "اليهود واليهودية في مملكة بيت المقدس",
    "Works about foreign relations of the United States": "أعمال عن علاقات الولايات المتحدة الخارجية",
    "Books about foreign relations of the United States": "كتب عن علاقات الولايات المتحدة الخارجية",
    "Men's national sports teams of the United States": "منتخبات رياضية وطنية رجالية في الولايات المتحدة",
    "wheelchair basketball players in turkey": "لاعبو كرة سلة على كراسي متحركة في تركيا",
    "field hockey players in germany": "لاعبو هوكي ميدان في ألمانيا",
    "baseball players in florida": "لاعبو كرة قاعدة في فلوريدا",
    "baseball players in south korea": "لاعبو كرة قاعدة في كوريا الجنوبية",
    "basketball players in lebanon": "لاعبو كرة سلة في لبنان",
    "sport in khartoum": "الرياضة في الخرطوم",
    "sport in ottoman empire": "الرياضة في الدولة العثمانية",
    "sport in tuzla": "الرياضة في توزلا",
    "sport in veria": "الرياضة في فيريا",
    "sport in álava": "الرياضة في ألافا (مقاطعة)",
    "Defunct political parties of Islamic Republic of Iran": "أحزاب سياسية سابقة في الجمهورية الإسلامية الإيرانية",
    "People executed by hanging by country": "أشخاص أعدموا حرقاً حسب البلد",
    "Cultural depictions of sportspeople": "تصوير ثقافي عن رياضيون",
    "Scheduled sports events": "أحداث رياضية مقررة",
    "ivorian people": "إيفواريون",
    "japanese lgbtq people": "أعلام إل جي بي تي كيو يابانيون",
    "chinese lgbtq people": "أعلام إل جي بي تي كيو صينيون",
    "arab lgbtq people": "أعلام إل جي بي تي كيو عرب",
    "rwandan political people": "ساسة روانديون",
    "maldivian people": "مالديفيون",
    "malian people": "ماليون",
    "maltese lgbtq people": "أعلام إل جي بي تي كيو مالطيون",
    "namibia–russia relations": "العلاقات الروسية الناميبية",
    "morocco–netherlands relations": "العلاقات المغربية الهولندية",
    "morocco–pakistan relations": "العلاقات الباكستانية المغربية",
    "morocco–qatar relations": "العلاقات القطرية المغربية",
    "morocco–russia relations": "العلاقات الروسية المغربية",
    "morocco–united kingdom relations": "العلاقات البريطانية المغربية",
    "mongolia–russia relations": "العلاقات الروسية المنغولية",
    "mauritania–morocco relations": "العلاقات المغربية الموريتانية",
    "mauritania–russia relations": "العلاقات الروسية الموريتانية",
    "south korea–united states relations": "العلاقات الأمريكية الكورية الجنوبية",
    "somalia–turkey relations": "العلاقات التركية الصومالية",
    "russia–sudan relations": "العلاقات الروسية السودانية",
    "russia–tunisia relations": "العلاقات التونسية الروسية",
    "russia–united arab emirates relations": "العلاقات الإماراتية الروسية",
    "russia–uzbekistan relations": "العلاقات الأوزبكستانية الروسية",
    "philippine–american war": "الحرب الأمريكية الفلبينية",
    "philippines–saudi arabia relations": "العلاقات السعودية الفلبينية",
    "palestine national basketball team": "منتخب فلسطين لكرة السلة",
    "russia men's national ice hockey team": "منتخب روسيا لهوكي الجليد للرجال",
    "palestine–united arab emirates relations": "العلاقات الإماراتية الفلسطينية",
    "palestine–united kingdom relations": "العلاقات البريطانية الفلسطينية",
    "palestine–uruguay relations": "العلاقات الأوروغويانية الفلسطينية",
    "african championships in athletics": "بطولات إفريقية في ألعاب القوى",
    "automotive industry in italy": "صناعة سيارات في إيطاليا",
    "bahrain in the asian para games": "البحرين في الألعاب البارالمبية الآسيوية",
    "field hockey in the 2004 summer olympics": "هوكي الميدان في الألعاب الأولمبية الصيفية 2004",
    "gymnastics in the 2004 summer olympics": "الجمباز في الألعاب الأولمبية الصيفية 2004",
    "history of the petroleum industry in canada": "تاريخ صناعة بترولية في كندا",
    "internet in bahrain": "إنترنت في البحرين",
    "islam in bermuda": "الإسلام في برمودا",
    "kingdom of hungary in the middle ages": "مملكة المجر في العصور الوسطى",
    "kurds in syria": "الأكراد في سوريا",
    "kurds in turkey": "الأكراد في تركيا",
    "protestantism in morocco": "البروتستانتية في المغرب",
    "protestantism in yemen": "البروتستانتية في اليمن",
    "same-sex marriage in the netherlands": "زواج مثلي في هولندا",
    "shia islam in afghanistan": "الشيعة في أفغانستان",
    "shooting in the 2004 summer olympics": "الرماية في الألعاب الأولمبية الصيفية 2004",
    "silver mining in the united states": "التنقيب عن الفضة في الولايات المتحدة",
    "swimming in the 2004 summer olympics": "السباحة في الألعاب الأولمبية الصيفية 2004",
    "synchronized swimming in the 2004 summer olympics": "السباحة المتزامنة في الألعاب الأولمبية الصيفية 2004",
    "taekwondo in the 2004 summer olympics": "التايكوندو في الألعاب الأولمبية الصيفية 2004",
    "time in azerbaijan": "الزمن في أذربيجان",
    "time in cyprus": "الزمن في قبرص",
    "triathlon in the 2004 summer olympics": "السباق الثلاثي في الألعاب الأولمبية الصيفية 2004",
    "women in niue": "المرأة في نييوي",
    "women in pala": "المرأة في بالاو",
    "women in the cook islands": "المرأة في جزر كوك",
    "women in the federated states of micronesia": "المرأة في ولايات ميكرونيسيا المتحدة",
    "women in the federated states-of micronesia": "المرأة في ولايات ميكرونيسيا المتحدة",
    "wrestling in the 2004 summer olympics": "المصارعة في الألعاب الأولمبية الصيفية 2004",
    "wrestling in the 2016 summer olympics": "المصارعة في الألعاب الأولمبية الصيفية 2016",
    "saudi arabia–ukraine relations": "العلاقات الأوكرانية السعودية",
    "china–sudan relations": "العلاقات السودانية الصينية",
    "china-sudan relations": "العلاقات السودانية الصينية",
    "saudi arabia-ukraine relations": "العلاقات الأوكرانية السعودية",
    "mauritania-morocco relations": "العلاقات المغربية الموريتانية",
    "mauritania-russia relations": "العلاقات الروسية الموريتانية",
    "mongolia-russia relations": "العلاقات الروسية المنغولية",
    "morocco-netherlands relations": "العلاقات المغربية الهولندية",
    "morocco-pakistan relations": "العلاقات الباكستانية المغربية",
    "morocco-qatar relations": "العلاقات القطرية المغربية",
    "morocco-russia relations": "العلاقات الروسية المغربية",
    "morocco-united kingdom relations": "العلاقات البريطانية المغربية",
    "namibia-russia relations": "العلاقات الروسية الناميبية",
    "palestine-united arab emirates relations": "العلاقات الإماراتية الفلسطينية",
    "palestine-united kingdom relations": "العلاقات البريطانية الفلسطينية",
    "palestine-uruguay relations": "العلاقات الأوروغويانية الفلسطينية",
    "philippines-saudi arabia relations": "العلاقات السعودية الفلبينية",
    "russia-sudan relations": "العلاقات الروسية السودانية",
    "russia-tunisia relations": "العلاقات التونسية الروسية",
    "russia-united arab emirates relations": "العلاقات الإماراتية الروسية",
    "russia-uzbekistan relations": "العلاقات الأوزبكستانية الروسية",
    "somalia-turkey relations": "العلاقات التركية الصومالية",
    "south korea-united states relations": "العلاقات الأمريكية الكورية الجنوبية",
    "lists of populated places in the united states": "قوائم أماكن مأهولة في الولايات المتحدة",
    "populated places in the british virgin islands": "أماكن مأهولة في جزر العذراء البريطانية",
    "soccer in australia": "كرة القدم في أستراليا",
    "soccer in the united states": "كرة القدم في الولايات المتحدة",
    "football in spain": "كرة القدم في إسبانيا",
    "water polo in the world aquatics championships": "كرة الماء في بطولة العالم للرياضات المائية",
    "populated places in tokelau": "أماكن مأهولة في توكيلاو",
    "townships in michigan": "ضواحي مدن في ميشيغان",
    "populated places in christmas island": "أماكن مأهولة في جزيرة عيد الميلاد",
    "cities and towns in india": "مدن وبلدات في الهند",
    "neighbourhoods in rio de janeiro (city)": "أحياء في ريو دي جانيرو",
    "populated places in the cocos (keeling) islands": "أماكن مأهولة في جزر كوكوس",
    "populated places in puebla": "أماكن مأهولة في ولاية بويبلا",
    "populated places in the cook islands": "أماكن مأهولة في جزر كوك",
    "populated places in norfolk island": "أماكن مأهولة في جزيرة نورفولك",
    "cities and towns in moscow oblast": "مدن وبلدات في محافظة موسكو",
    "wheelchair basketball world championship": "بطولة العالم لكرة السلة على الكراسي المتحركة",
    "water polo at the world aquatics championships": "كرة الماء في بطولة العالم للرياضات المائية",
    "portugal national rugby league team": "منتخب البرتغال لدوري الرجبي",
    "new zealand women's national ice hockey team": "منتخب نيوزيلندا لهوكي الجليد للسيدات",
    "new zealand women's national rugby league team": "منتخب نيوزيلندا لدوري الرجبي للسيدات",
    "kazakhstan women's national ice hockey team": "منتخب كازاخستان لهوكي الجليد للسيدات",
    "georgia national rugby union team": "منتخب جورجيا لاتحاد الرجبي",
    "england women's national rugby league team": "منتخب إنجلترا لدوري الرجبي للسيدات",
    "chile national rugby union team": "منتخب تشيلي لاتحاد الرجبي",
    "australia national rugby union team": "منتخب أستراليا لاتحاد الرجبي",
    "algeria national rugby union team": "منتخب الجزائر لاتحاد الرجبي",
    "united states national rugby union team": "منتخب الولايات المتحدة لاتحاد الرجبي",
    "greece national rugby league team": "منتخب اليونان لدوري الرجبي",
    "archery at the 2004 summer olympics": "النبالة في الألعاب الأولمبية الصيفية 2004",
    "wrestling at the 2004 summer olympics": "المصارعة في الألعاب الأولمبية الصيفية 2004",
    "triathlon at the 2004 summer olympics": "السباق الثلاثي في الألعاب الأولمبية الصيفية 2004",
    "synchronized swimming at the 2004 summer olympics": "السباحة المتزامنة في الألعاب الأولمبية الصيفية 2004",
    "united states national futsal team": "منتخب الولايات المتحدة لكرة الصالات",
    "thailand women's national basketball team": "منتخب تايلاند لكرة السلة للسيدات",
    "sweden national bandy team": "منتخب السويد للباندي",
    "slovenia women's national football team": "منتخب سلوفينيا لكرة القدم للسيدات",
    "papua new guinea women's national football team": "منتخب بابوا غينيا الجديدة لكرة القدم للسيدات",
    "netherlands men's national basketball team": "منتخب هولندا لكرة السلة للرجال",
    "taekwondo at the 2004 summer olympics": "التايكوندو في الألعاب الأولمبية الصيفية 2004",
    "namibia women's national football team": "منتخب ناميبيا لكرة القدم للسيدات",
    "myanmar women's national football team": "منتخب ميانمار لكرة القدم للسيدات",
    "montenegro women's national football team": "منتخب الجبل الأسود لكرة القدم للسيدات",
    "moldova national rugby league team": "منتخب مولدوفا لدوري الرجبي",
    "moldova women's national football team": "منتخب مولدوفا لكرة القدم للسيدات",
    "philippine football federation": "الاتحاد الفلبيني لكرة القدم",
    "iraq national football team results": "نتائج منتخب العراق لكرة القدم",
    "austria women's national football team": "منتخب النمسا لكرة القدم للسيدات",
    "algeria women's national football team": "منتخب الجزائر لكرة القدم للسيدات",
    "thailand women's national football team": "منتخب تايلاند لكرة القدم للسيدات",
    "switzerland women's national football team": "منتخب سويسرا لكرة القدم للسيدات",
    "portugal women's national football team": "منتخب البرتغال لكرة القدم للسيدات",
    "vietnam national basketball team": "منتخب فيتنام لكرة السلة",
    "uruguay national football team": "منتخب أوروغواي لكرة القدم",
    "bolivia national soccer team": "منتخب بوليفيا لكرة القدم",
}

data_2 = {
    "Austrian Giro d'Italia stage winners": "فائزون في مراحل طواف إيطاليا نمساويون",
    "Azerbaijani men marathon runners": "عداؤو ماراثون أذربيجانيون",
    "Brazilian men sprinters": "عداؤون سريعون برازيليون",
    "Burmese men long-distance runners": "عداؤو مسافات طويلة بورميون",
    "Estonian men long-distance runners": "عداؤو مسافات طويلة إستونيون",
    "Gibraltarian men athletes": "لاعبو قوى جبل طارقيون",
    "Nazis executed by the British military": "نازيون أعدموا من قبل الجيش البريطاني",
    "People executed by the British military": "أشخاص أعدموا من قبل الجيش البريطاني",
    "People executed by the French military": "أشخاص أعدموا من قبل الجيش الفرنسي",
    "women in danish military": "المرأة في الجيش الدنماركي",
    "brazilian women's rights activists": "برازيليون ناشطون في حقوق المرأة",
    "burmese men marathon runners": "عداؤو ماراثون بورميون",
    "canadian men": "رجال كنديون",
    "Men's basketball players from Northern Ireland": "لاعبو كرة سلة من أيرلندا الشمالية",
    "Men's footballers in Papua New Guinea": "لاعبو كرة قدم في بابوا غينيا الجديدة",
    "men's footballers in togo": "لاعبو كرة قدم في توغو",
    "puerto rican men high jumpers": "متسابقو قفز عالي بورتوريكيون",
    "turkish women's rights activists": "أتراك ناشطون في حقوق المرأة",
    "Chilean men shot putters": "لاعبو دفع ثقل تشيليون",
    "Somalian men sprinters": "عداؤون سريعون صوماليون",
    "Sculptures of men in England": "منحوتات في رجال في إنجلترا",
    "Sculptures of men in London": "منحوتات في رجال في لندن",
    "Algerian men middle-distance runners": "عداؤو مسافات متوسطة جزائريون",
    "Guatemalan men middle-distance runners": "عداؤو مسافات متوسطة غواتيماليون",
    "Haitian men athletes": "لاعبو قوى هايتيون",
    "Iranian men athletes": "لاعبو قوى إيرانيون",
    "Iraqi men middle-distance runners": "عداؤو مسافات متوسطة عراقيون",
    "Kyrgyzstani men marathon runners": "عداؤو ماراثون قيرغيزستانيون",
    "Liechtenstein men sprinters": "عداؤون سريعون ليختنشتانيون",
    "Macedonian men sprinters": "عداؤون سريعون مقدونيون",
    "Men discus throwers": "رماة قرص",
    "Men's footballers in Mongolia": "لاعبو كرة قدم في منغوليا",
    "Nicaraguan men high jumpers": "متسابقو قفز عالي نيكاراغويون",
    "Russian men pole vaulters": "قافزون بالزانة روس",
    "Taiwanese men long jumpers": "لاعبو قفز طويل تايوانيون",
    "Trinidad and Tobago men discus throwers": "رماة قرص ترنيداديون",
    "Abolitionists from Wisconsin": "مناهضون للعبودية من ويسكونسن",
    "Albanian women's rights activists": "ألبان ناشطون في حقوق المرأة",
    "Botswana women's rights activists": "بوتسوانيون ناشطون في حقوق المرأة",
    "Venezuelan women's rights activists": "فنزويليون ناشطون في حقوق المرأة",
}

data_3 = {
    "africanamerican–jewish relations": "العلاقات الأمريكية الإفريقية اليهودية",
    "african–native american relations": "العلاقات الأمريكية الأصلية الإفريقية",
    "arab–american relations": "العلاقات الأمريكية العربية",
    "native american–jewish relations": "العلاقات الأمريكية الأصلية اليهودية",
    "roman–iranian relations": "العلاقات الإيرانية الرومانية",
    "1009 works": "أعمال 1009",
    "1013 works": "أعمال 1013",
    "10th-century BC architecture": "عمارة القرن 10 ق م",
    "1239 works": "أعمال 1239",
    "1261 works": "أعمال 1261",
    "1265 works": "أعمال 1265",
    "12th iranian majlis": "المجلس الإيراني الثاني عشر",
    "1370s conflicts": "نزاعات في عقد 1370",
    "13th iranian majlis": "المجلس الإيراني الثالث عشر",
    "13th-century plays": "مسرحيات القرن 13",
    "1429 in law": "القانون في 1429",
    "1483 works": "أعمال 1483",
    "1562 works": "أعمال 1562",
    "15th iranian majlis": "المجلس الإيراني الخامس عشر",
    "1630s natural disasters": "كوارث طبيعية في عقد 1630",
    "1701 in international relations": "علاقات دولية في 1701",
    "1708 in law": "القانون في 1708",
    "1727 in law": "القانون في 1727",
    "1737 in music": "موسيقى في 1737",
    "1752 works": "أعمال 1752",
    "1793 elections": "انتخابات 1793",
    "1795 in mass media": "وسائل إعلام في 1795",
    "17th-century Dutch books": "كتب هولندية في القرن 17",
    "17th-century plays": "مسرحيات القرن 17",
    "1817 treaties": "معاهدات في 1817",
    "1826 murders by continent": "جرائم قتل في 1826 حسب القارة",
    "1830s documents": "وثائق في عقد 1830",
    "1832 works": "أعمال 1832",
    "1833 in mass media": "وسائل إعلام في 1833",
    "1835 meteorology": "الأرصاد الجوية في 1835",
    "1842 in mass media": "وسائل إعلام في 1842",
    "1854 in law": "القانون في 1854",
    "1855 disasters by country": "كوارث في 1855 حسب البلد",
    "1866 asian winter games": "الألعاب الآسيوية الشتوية 1866",
    "1866 european games": "الألعاب الأوروبية 1866",
    "1866 indian general election": "الانتخابات العامة الهندية 1866",
    "1866 pan american games": "دورة الألعاب الأمريكية 1866",
    "1866 parapan american games": "ألعاب بارابان الأمريكية 1866",
    "1866 presidential candidates": "مرشحون رئاسيون في 1866",
    "1866 sea games": "ألعاب البحر 1866",
    "1866 summer olympics": "الألعاب الأولمبية الصيفية 1866",
    "1866 summer paralympics": "الألعاب البارالمبية الصيفية 1866",
    "1866 united states elections": "انتخابات الولايات المتحدة في 1866",
    "1866 united states": "الولايات المتحدة في 1866",
    "1867 in mass media": "وسائل إعلام في 1867",
    "18th-century attacks on Jewish institutions": "هجمات القرن 18 في مؤسسات يهودية",
    "1902 in music by country": "موسيقى في 1902 حسب البلد",
    "1904 murders by country": "جرائم قتل في 1904 حسب البلد",
    "1909 murders by country": "جرائم قتل في 1909 حسب البلد",
    "1910 in international relations": "علاقات دولية في 1910",
    "1917 in music": "موسيقى في 1917",
    "1934 murders": "جرائم قتل في 1934",
    "1948 in law": "القانون في 1948",
    "1948 treaties": "معاهدات في 1948",
    "1965 in music by country": "موسيقى في 1965 حسب البلد",
    "1970s elections": "انتخابات عقد 1970",
    "1971–72 in Northern Ireland association football": "كرة القدم الأيرلندية الشمالية في 1971–72",
    "1972 murders": "جرائم قتل في 1972",
    "1990 in international relations": "علاقات دولية في 1990",
    "1990s television series debuts": "مسلسلات تلفزيونية بدأ عرضها في عقد 1990",
    "1999 disasters by country": "كوارث في 1999 حسب البلد",
    "19th-century books": "كتب القرن 19",
    "1st-century architecture": "عمارة القرن 1",
    "1st-millennium architecture": "عمارة الألفية 1",
    "2021 meteorology": "الأرصاد الجوية في 2021",
    "2024 disasters by country": "كوارث في 2024 حسب البلد",
    "2025–26 in Northern Ireland association football": "كرة القدم الأيرلندية الشمالية في 2025–26",
    "2026 elections by country": "انتخابات 2026 حسب البلد",
    "2026 in music by country": "موسيقى في 2026 حسب البلد",
    "2026 television series debuts": "مسلسلات تلفزيونية بدأ عرضها في 2026",
    "20th-century Anglican archbishops in Ireland": "رؤساء أساقفة أنجليكيون في القرن 20 في أيرلندا",
    "20th-century Anglican archbishops in New Zealand": "رؤساء أساقفة أنجليكيون في القرن 20 في نيوزيلندا",
    "20th-century attacks on Jewish institutions in United States": "هجمات القرن 20 على مؤسسات يهودية في الولايات المتحدة",
    "20th-century attacks on Jewish institutions": "هجمات القرن 20 في مؤسسات يهودية",
    "20th-century executions by Papua New Guinea": "إعدامات في القرن 20 في بابوا غينيا الجديدة",
    "21st-century Anglican archbishops in New Zealand": "رؤساء أساقفة أنجليكيون في القرن 21 في نيوزيلندا",
    "21st-century attacks on Jewish institutions in United States": "هجمات القرن 21 على مؤسسات يهودية في الولايات المتحدة",
    "21st-century attacks on Jewish institutions": "هجمات القرن 21 في مؤسسات يهودية",
    "3rd-century paintings": "لوحات القرن 3",
    "3rd-millennium works": "أعمال الألفية 3",
    "60s conflicts": "نزاعات في عقد 60",
    "April 1959 in sports": "ألعاب رياضية في أبريل 1959",
    "April 2026 in sports": "ألعاب رياضية في أبريل 2026",
    "Attacks on Jewish institutions by century": "هجمات على مؤسسات يهودية حسب القرن",
    "Attacks on Jewish institutions in Poland": "هجمات على مؤسسات يهودية في بولندا",
    "Attacks on Jewish institutions in United States": "هجمات على مؤسسات يهودية في الولايات المتحدة",
    "Attacks on Jewish institutions": "هجمات على مؤسسات يهودية",
    "August 2026 in sports": "ألعاب رياضية في أغسطس 2026",
    "Bishops of Ripon and Leeds": "أساقفة من ريبون (شمال يوركشير) وليدز",
    "british columbia (1866–1866)": "كولومبيا البريطانية (1866–1866)",
    "COVID-19 pandemic in Papua New Guinea templates": "قوالب جائحة فيروس كورونا في بابوا غينيا الجديدة",
    "Deaths by airstrike during the Syrian civil war": "وفيات بضربات جوية خلال الحرب الأهلية السورية",
    "Deaths by airstrike during World War II": "وفيات بضربات جوية خلال الحرب العالمية الثانية",
    "Deaths by airstrike": "وفيات بضربات جوية",
    "December 2007 in sports": "ألعاب رياضية في ديسمبر 2007",
    "democratic-republic-of-congo–republic-of ireland relations": "العلاقات الأيرلندية الكونغوية الديمقراطية",
    "Educational institutions established in 2009": "هيئات تعليمية أسست في 2009",
    "February 2026 in sports": "ألعاب رياضية في فبراير 2026",
    "Fiction set in 1716": "أعمال خيالية في 1716",
    "Fiction set in 1790s": "أعمال خيالية في عقد 1790",
    "Fiction set in 1819": "أعمال خيالية في 1819",
    "Fiction set in 27th century": "أعمال خيالية في القرن 27",
    "Healthcare by city of the United States": "الرعاية الصحية حسب المدينة في الولايات المتحدة",
    "January 1901 in sports": "ألعاب رياضية في يناير 1901",
    "January 1952 in sports": "ألعاب رياضية في يناير 1952",
    "January 2026 in sports": "ألعاب رياضية في يناير 2026",
    "July 2026 in sports": "ألعاب رياضية في يوليو 2026",
    "June 1956 in sports": "ألعاب رياضية في يونيو 1956",
    "June 2026 in sports": "ألعاب رياضية في يونيو 2026",
    "Lists of organisations based in Papua New Guinea": "قوائم منظمات مقرها في بابوا غينيا الجديدة",
    "Lists of people executed in the United States by year": "قوائم أشخاص أعدموا في الولايات المتحدة حسب السنة",
    "Lists of people executed in United States by year": "قوائم أشخاص أعدموا في الولايات المتحدة حسب السنة",
    "March 2026 in sports": "ألعاب رياضية في مارس 2026",
    "May 1946 in sports": "ألعاب رياضية في مايو 1946",
    "May 1993 in sports": "ألعاب رياضية في مايو 1993",
    "May 2026 in sports": "ألعاب رياضية في مايو 2026",
    "muslim people templates": "قوالب مسلمون",
    "northern-ireland football cups": "كؤوس كرة القدم الأيرلندية الشمالية",
    "November 2026 in sports": "ألعاب رياضية في نوفمبر 2026",
    "October 1922 in sports": "ألعاب رياضية في أكتوبر 1922",
    "People executed in British North America by hanging": "أشخاص أعدموا في أمريكا الشمالية البريطانية حسب بالشنق",
    "People executed in the Holy Roman Empire by burning": "أشخاص أعدموا في الإمبراطورية الرومانية المقدسة حسب بالحرق",
    "People executed in the Holy Roman Empire by decapitation": "أشخاص أعدموا في الإمبراطورية الرومانية المقدسة حسب بقطع الرأس",
    "republic of ireland women's national football team": "منتخب جمهورية أيرلندا لكرة القدم للسيدات",
    "republic-of ireland–united kingdom border crossings": "معابر الحدود الأيرلندية البريطانية",
    "republic-of ireland–united kingdom border": "الحدود الأيرلندية البريطانية",
    "second polish republic (1866–1866)": "الجمهورية البولندية الثانية (1866–1866)",
    "September 2024 in sports": "ألعاب رياضية في سبتمبر 2024",
    "September 2026 in sports": "ألعاب رياضية في سبتمبر 2026",
    "south korean presidential election 2017": "انتخابات الرئاسة الكورية الجنوبية 2017",
    "Transport companies established in 1946": "شركات نقل أسست في 1946",
    "Transport infrastructure completed in 1916": "بنية تحتية للنقل اكتملت في 1916",
    "Transport infrastructure completed in 1972": "بنية تحتية للنقل اكتملت في 1972",
    "Transport infrastructure completed in 21st century": "بنية تحتية للنقل اكتملت في القرن 21",
    "uefa euro 1866": "بطولة أمم أوروبا 1866",
    "united kingdom (1866–1866)": "المملكة المتحدة (1866–1866)",
    "war in iraq (1866–1866)": "الحرب في العراق (1866–1866)",
}


@pytest.mark.parametrize("category, expected", data_2.items(), ids=data_2.keys())
@pytest.mark.fast
def test_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


to_test = [
    ("test_1", data_1),
    ("test_2", data_2),
    ("test_3", data_3),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)



#!/usr/bin/python3
"""
Resolver Factory Module

This module wires together all the resolver components and breaks the circular
dependency by setting up callbacks at runtime after all modules are loaded.

IMPORTANT: The `initialize_resolvers()` function must be called explicitly
after all modules are imported to set up the callbacks. This is done in
`legacy_bots/__init__.py`.
"""

from __future__ import annotations

from ...fix import fixtitle


def translate_general_category_wrap(category: str) -> str:
    """
    Resolve an Arabic label for a general category using layered resolvers.

    This function combines sub_translate_general_category and work_separator_names
    to provide comprehensive category resolution.

    Parameters:
        category (str): The input category string to resolve.

    Returns:
        str: Arabic label for the category, or an empty string if unresolved.
    """
    from .separator_based_resolver import work_separator_names
    from .sub_resolver import sub_translate_general_category

    arlabel = "" or sub_translate_general_category(category) or work_separator_names(category)
    if arlabel:
        arlabel = fixtitle.fixlabel(arlabel, en=category)
    return arlabel


def _translate_general_no_fixtitle(category: str) -> str:
    """
    Resolve an Arabic label for a general category without fixtitle.

    This version is used as a callback for with_years_bot.
    """
    from .separator_based_resolver import work_separator_names
    from .sub_resolver import sub_translate_general_category

    return "" or sub_translate_general_category(category) or work_separator_names(category)


_initialized = False


def initialize_resolvers() -> None:
    """
    Initialize all callback resolvers.

    This function must be called after all resolver modules are loaded.
    It sets up the callbacks that break the circular dependencies.
    """
    global _initialized
    if _initialized:
        return

    from ..legacy_resolvers_bots.country2_label_bot import set_term_label_resolver
    from ..legacy_resolvers_bots.with_years_bot import set_translate_callback
    from .country_resolver import fetch_country_term_label, set_fallback_resolver

    # Set up the fallback resolver for country_resolver
    set_fallback_resolver(translate_general_category_wrap)

    # Set up the term label resolver for country2_label_bot
    def term_label_wrapper(term: str, separator: str, lab_type: str = "") -> str:
        return fetch_country_term_label(term, separator, lab_type=lab_type)

    set_term_label_resolver(term_label_wrapper)

    # Set up the translate callback for with_years_bot
    set_translate_callback(_translate_general_no_fixtitle)

    _initialized = True


__all__ = [
    "translate_general_category_wrap",
    "initialize_resolvers",
]



#!/usr/bin/python3
"""
Country Resolver Module

This module handles country-related label resolution using layered lookup strategies.
It is extracted from the legacy circular_dependency package to break the import cycle.

The key architectural change is that this module does NOT import from arabic_label_builder
or separator_based_resolver. Instead, it accepts callback functions for fallback resolution.
"""

from __future__ import annotations

import functools
import logging
import re
from typing import Callable, Optional

from ...fix import fixtitle
from ...new_resolvers import all_new_resolvers
from ...sub_new_resolvers import team_work
from ...sub_new_resolvers.peoples_resolver import work_peoples
from ...time_formats.time_to_arabic import convert_time_to_arabic
from ...translations import (
    New_female_keys,
    jobs_mens_data,
    keys_of_without_in,
    religious_entries,
)
from ..common_resolver_chain import get_lab_for_country2
from ..legacy_resolvers_bots.bot_2018 import get_pop_All_18
from ..legacy_resolvers_bots.country2_label_bot import country_2_title_work
from ..legacy_utils.joint_class import CountryLabelAndTermParent
from ..make_bots import get_KAKO

logger = logging.getLogger(__name__)

# Type alias for the fallback resolver callback
FallbackResolver = Callable[[str, bool], str]

# Module-level callback holder - set via set_fallback_resolver()
_fallback_resolver: Optional[FallbackResolver] = None


def set_fallback_resolver(resolver: FallbackResolver) -> None:
    """
    Set the fallback resolver callback.

    This is used to break the circular dependency. The fallback resolver
    (typically translate_general_category_wrap) is injected at runtime
    after all modules are loaded.

    Parameters:
        resolver: A callable that takes (category: str)
                  and returns an Arabic label string.
    """
    global _fallback_resolver
    _fallback_resolver = resolver


def _get_fallback_label(category: str) -> str:
    """
    Get label from the fallback resolver if one is set.

    Parameters:
        category: The category string to resolve.

    Returns:
        The resolved label from the fallback resolver, or empty string if not set.
    """
    if _fallback_resolver is not None:
        return _fallback_resolver(category)
    return ""


@functools.lru_cache(maxsize=10000)
def Get_country2(country: str) -> str:
    """
    Resolve a country name to its Arabic label.

    The resolved label is formatted for title consistency and normalized to remove extra whitespace.

    Parameters:
        country (str): Country name to resolve (case-insensitive; will be lower-cased and stripped).

    Returns:
        str: The Arabic label with title formatting applied and normalized whitespace, or an empty string if unresolved.
    """

    country = country.lower().strip()
    logger.info(f'>> "{country}":')

    resolved_label = (
        country_2_title_work(country, with_years=True)
        or get_lab_for_country2(country)
        or get_pop_All_18(country)
        or get_KAKO(country)
        or _get_fallback_label(country)
        or ""
    )

    if resolved_label:
        resolved_label = fixtitle.fixlabel(resolved_label, en=country)

    resolved_label = " ".join(resolved_label.strip().split())

    logger.info(f'>> "{country}": cnt_la: {resolved_label}')

    return resolved_label


def _validate_separators(country: str) -> bool:
    """
    Return whether the input contains any disallowed separator phrases.

    Checks for presence of common separator words/phrases (for example " in ", " of ", or the special "-of ")
    and returns True only when none are found.

    Returns:
        True if no disallowed separators are present, False otherwise.
    """
    separators = [
        "based in",
        "in",
        "by",
        "about",
        "to",
        "of",
        "-of ",  # special case
        "from",
        "at",
        "on",
    ]
    separators = [f" {sep} " if sep != "-of " else sep for sep in separators]
    for sep in separators:
        if sep in country:
            return False
    return True


def check_historical_prefixes(country: str) -> str:
    """
    Resolve Arabic labels for strings that start with a historical prefix.

    If the input begins with a recognized historical prefix (e.g., "defunct national ...")
    and the remainder resolves to a label, return the prefix-specific formatted Arabic label;
    otherwise return an empty string.

    Parameters:
        country (str): The input string to inspect and resolve.

    Returns:
        str: The formatted Arabic label for the historical-prefixed term,
             or an empty string if no prefix matched or the remainder could not be resolved.
    """
    historical_prefixes = {
        "defunct national": "{} وطنية سابقة",
    }
    country = country.lower().strip()
    if not _validate_separators(country):
        return ""

    for prefix, prefix_template in historical_prefixes.items():
        if country.startswith(f"{prefix} "):
            logger.debug(f">>> country.startswith({prefix})")
            remainder = country[len(prefix) :].strip()
            remainder_label = Get_country2(remainder)

            if remainder_label:
                resolved_label = prefix_template.format(remainder_label)
                if remainder_label.strip().endswith(" في") and prefix.startswith("defunct "):
                    resolved_label = f"{remainder_label.strip()[: -len(' في')]} سابقة في"
                logger.info(f'>>>>>> cdcdc new cnt_la "{resolved_label}" ')
                return resolved_label
    return ""


class CountryLabelRetriever(CountryLabelAndTermParent):
    """A class to handle the retrieval of country labels and related terms.

    This class provides methods to look up and process country names,
    applying various transformations and resolution strategies to generate
    appropriate Arabic labels.
    """

    def __init__(self) -> None:
        """
        Initialize the CountryLabelRetriever.

        No runtime initialization is performed; the constructor exists to allow instantiation.
        """
        super().__init__(_resolve_callable=Get_country2)

    def get_country_label(self, country: str) -> str:
        """
        Resolve an Arabic label for a country name using layered lookup strategies.

        Parameters:
            country (str): Country name to resolve; case is normalized internally.

        Returns:
            str: The resolved Arabic label, or an empty string if no label is found.
        """
        country = country.lower()

        logger.debug(">> ----------------- start ----------------- ")
        logger.debug(f"<<yellow>> start {country=}")

        resolved_label = self._check_basic_lookups(country)

        if not resolved_label:
            resolved_label = (
                Get_country2(country)
                or self._check_prefixes(country)
                or check_historical_prefixes(country)
                or all_new_resolvers(country)
                or self._check_regex_years(country)
                or self._check_members(country)
                or ""
            )

        if resolved_label:
            if "سنوات في القرن" in resolved_label:
                resolved_label = re.sub(r"سنوات في القرن", "سنوات القرن", resolved_label)

        logger.info(f"<<yellow>> end {country=}, {resolved_label=}")
        return resolved_label

    def _check_basic_lookups(self, country: str) -> str:
        """
        Lookup a country in simple/local resolver tables and return the first matching label.

        If the input is a string of digits, it is returned unchanged.

        Parameters:
            country: Lowercase country/term as a string to resolve using basic lookup sources.

        Returns:
            The first matching label from basic lookup sources, or an empty string if none is found.
        """
        if country.strip().isdigit():
            return country

        label = (
            New_female_keys.get(country, "")
            or religious_entries.get(country, "")
            or work_peoples(country)
            or all_new_resolvers(country)
            or team_work.resolve_clubs_teams_leagues(country)
        )
        return label

    def fetch_country_term_label(self, term_lower: str, separator: str, lab_type: str = "") -> str:
        """
        Resolve an Arabic label for a given term (country, event, or category) using layered fallbacks.

        Parameters:
            term_lower (str): The input term in lowercase.
            separator (str): Context separator (e.g., "for", "in") that can affect resolution and recursion.
            lab_type (str): If "type_label", apply specialized suffix-handling logic to produce a type-related label.

        Returns:
            str: The resolved Arabic label, or an empty string if no resolution is found.
        """
        logger.info(f' {lab_type=}, {separator=}, c_ct_lower:"{term_lower}" ')

        # Check for numeric/empty terms
        test_numeric = re.sub(r"\d+", "", term_lower.strip())
        if test_numeric in ["", "-", "–", "−"]:
            return term_lower

        term_label = New_female_keys.get(term_lower, "") or religious_entries.get(term_lower, "")
        if not term_label:
            term_label = convert_time_to_arabic(term_lower)

        if term_label == "" and lab_type != "type_label":
            if term_lower.startswith("the "):
                logger.info(f'>>>> {term_lower=} startswith("the ")')
                term_without_the = term_lower[len("the ") :]
                term_label = get_pop_All_18(term_without_the, "")
                if not term_label:
                    term_label = self.get_country_label(term_without_the)

        if not term_label:
            if re.sub(r"\d+", "", term_lower) == "":
                term_label = term_lower
            else:
                term_label = convert_time_to_arabic(term_lower)

        if term_label == "":
            term_label = self.get_country_label(term_lower)

        if not term_label and lab_type == "type_label":
            term_label = self._handle_type_lab_logic(term_lower, separator)

        if term_label:
            logger.info(f" {term_label=} ")
        elif separator.strip() == "for" and term_lower.startswith("for "):
            return self.fetch_country_term_label(term_lower[len("for ") :], "", lab_type=lab_type)

        return term_label

    def _handle_type_lab_logic(self, term_lower: str, separator: str) -> str:
        """
        Resolve a label for terms treated as types that end with suffixes like " of", " in", or " at".

        Parameters:
            term_lower (str): Lowercased term to process (may end with " of", " in", or " at").
            separator (str): Separator context such as "in" that can alter fallback behaviour.

        Returns:
            str: The resolved Arabic label for the term, or an empty string if no label is found.
        """
        suffixes = [" of", " in", " at"]
        term_label = ""

        for suffix in suffixes:
            if not term_lower.endswith(suffix):
                continue

            base_term = term_lower[: -len(suffix)]
            translated_base = jobs_mens_data.get(base_term, "")

            logger.info(f" {base_term=}, {translated_base=}, {term_lower=} ")

            if term_label == "" and translated_base:
                term_label = f"{translated_base} من "
                logger.info(f"jobs_mens_data:: add من to {term_label=}, line:1583.")

            if not translated_base:
                translated_base = get_pop_All_18(base_term, "")

            if not translated_base:
                translated_base = self.get_country_label(base_term)

            if term_label == "" and translated_base:
                if term_lower in keys_of_without_in:
                    term_label = translated_base
                    logger.info("skip add في to keys_of_without_in")
                else:
                    term_label = f"{translated_base} في "
                    logger.info(f"XX add في to {term_label=}, line:1596.")
                return term_label  # Return immediately if found

        if term_label == "" and separator.strip() == "in":
            term_label = get_pop_All_18(f"{term_lower} in", "")

        if not term_label:
            term_label = self.get_country_label(term_lower)

        return term_label


# Instantiate the retriever
_retriever = CountryLabelRetriever()


def event2_d2(category_r: str) -> str:
    """Determine the category label based on the input string.

    Args:
        category_r: The raw category string to process

    Returns:
        The processed category label or an empty string if not found
    """
    cat3 = category_r.lower().replace("category:", "").strip()

    logger.info(f'<<lightred>>>>>> category33:"{cat3}" ')

    # Reject strings that contain common English prepositions
    blocked = ("in", "of", "from", "by", "at")
    if any(f" {word} " in cat3.lower() for word in blocked):
        return ""

    category_lab = ""
    if re.sub(r"^\d", "", cat3) == cat3:
        category_lab = get_country_label(cat3)

    return category_lab


def get_country_label(country: str) -> str:
    """Retrieve the Arabic label for a given country name.

    Args:
        country: The country name to look up

    Returns:
        The Arabic label for the country or an empty string if not found
    """
    return _retriever.get_country_label(country)


def fetch_country_term_label(term_lower: str, separator: str, lab_type: str = "") -> str:
    """
    Retrieve an Arabic label for a given term or country name using layered resolution strategies.

    Parameters:
        term_lower (str): The lowercase term to look up.
        separator (str): Context separator used when resolving terms (e.g., "for", "in").
        lab_type (str): Optional label type that enables special handling (e.g., "type_label").

    Returns:
        str: The resolved Arabic label for the term, or an empty string if no label is found.
    """
    return _retriever.fetch_country_term_label(term_lower, separator, lab_type=lab_type)


__all__ = [
    "fetch_country_term_label",
    "get_country_label",
    "Get_country2",
    "event2_d2",
    "set_fallback_resolver",
]



#
import pytest

from ArWikiCats import resolve_label_ar
from utils.dump_runner import make_dump_test_name_data

data0 = {
    "Women's sports clubs and teams in Afghanistan": "أندية وفرق رياضية نسائية في أفغانستان",
    # "Women's sports seasons": "مواسم رياضات نسائية",
}

data1 = {
    "American women's sports": "رياضات نسائية أمريكية",
    "Women's sports by dependent territory": "رياضات نسائية حسب الأقاليم التابعة",
    "women's sports clubs": "أندية رياضية نسائية",
    "women's sports competitions": "منافسات رياضية نسائية",
    "women's sports leagues": "دوريات رياضية نسائية",
    "women's sports organizations": "منظمات رياضية نسائية",
    "women's sports teams": "فرق رياضية نسائية",
    "national women's sports teams": "منتخبات رياضية وطنية نسائية",
    "college women's sports teams in united states": "فرق رياضات الكليات للسيدات في الولايات المتحدة",
    "mexican women's sports": "رياضات نسائية مكسيكية",
    "canadian women's sports": "رياضات نسائية كندية",
    "american women's sports": "رياضات نسائية أمريكية",
    "2026 in American women's sports": "رياضات نسائية أمريكية في 2026",
    "1964 in American women's sports": "رياضات نسائية أمريكية في 1964",
    "1972 in American women's sports": "رياضات نسائية أمريكية في 1972",
    "2003 in Canadian women's sports": "رياضات نسائية كندية في 2003",
    "Defunct women's sports clubs and teams": "",
    "Women's sport by continent and period": "رياضة نسائية حسب القارة والحقبة",
    "Women's sport by period": "رياضة نسائية حسب الحقبة",
    "Women's sport in Mexico City": "رياضة نسائية في مدينة مكسيكو",
    "Women's sport in Oceania by period": "رياضة نسائية في أوقيانوسيا حسب الحقبة",
}

data2 = {
    "Summer Olympics sports navigational boxes": "صناديق تصفح رياضات الألعاب الأولمبية الصيفية",
    "Winter Olympics sports navigational boxes": "صناديق تصفح رياضات الألعاب الأولمبية الشتوية",
    "Former Olympic sports": "رياضات أولمبية سابقة",
    "Ancient Olympic sports": "رياضات أولمبية قديمة",
    "Summer Olympic sports": "رياضات الألعاب الأولمبية الصيفية",
    "Winter Olympics sports templates": "قوالب رياضات الألعاب الأولمبية الشتوية",
    "Summer Olympics sports templates": "قوالب رياضات الألعاب الأولمبية الصيفية",
    "Winter Olympics sports": "رياضات الألعاب الأولمبية الشتوية",
    "Summer Olympics sports": "رياضات الألعاب الأولمبية الصيفية",
    "Azerbaijan sports navigational boxes": "صناديق تصفح الرياضة في أذربيجان",
    "Austria sports navigational boxes": "صناديق تصفح الرياضة في النمسا",
    "wheelchair sports": "ألعاب رياضية على الكراسي المتحركة",
}

to_test = [
    ("test_sports2_data_0", data0),
    ("test_sports2_data_1", data1),
    ("test_sports2_data_2", data2),
]


@pytest.mark.parametrize("category, expected", data0.items(), ids=data0.keys())
@pytest.mark.fast
def test_sports2_data_0(category: str, expected: str) -> None:
    """
    pytest tests/event_lists/womens/test_womens_sports2.py::test_sports2_data_0
    """
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.fast
def test_sports2_data_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
@pytest.mark.fast
def test_sports2_data_2(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


test_dump_all = make_dump_test_name_data(to_test, resolve_label_ar, run_same=False)



"""Aggregate translation tables for country and region labels."""

from __future__ import annotations

from ..data_builders.build_labels_country import (
    _build_country_label_index,
    _make_japan_labels,
    _make_turkey_labels,
)
from ..helps import len_print
from ._shared import load_json_mapping

US_STATES = {
    "georgia (u.s. state)": "ولاية جورجيا",
    "new york (state)": "ولاية نيويورك",
    "washington (state)": "ولاية واشنطن",
    "washington": "واشنطن",
    "washington, d.c.": "واشنطن العاصمة",
    "georgia": "جورجيا",
    "new york": "نيويورك",
    "alabama": "ألاباما",
    "alaska": "ألاسكا",
    "arizona": "أريزونا",
    "arkansas": "أركنساس",
    "california": "كاليفورنيا",
    "colorado": "كولورادو",
    "connecticut": "كونيتيكت",
    "delaware": "ديلاوير",
    "florida": "فلوريدا",
    "hawaii": "هاواي",
    "idaho": "أيداهو",
    "illinois": "إلينوي",
    "indiana": "إنديانا",
    "iowa": "آيوا",
    "kansas": "كانساس",
    "kentucky": "كنتاكي",
    "louisiana": "لويزيانا",
    "maine": "مين",
    "maryland": "ماريلند",
    "massachusetts": "ماساتشوستس",
    "michigan": "ميشيغان",
    "minnesota": "منيسوتا",
    "mississippi": "مسيسيبي",
    "missouri": "ميزوري",
    "montana": "مونتانا",
    "nebraska": "نبراسكا",
    "nevada": "نيفادا",
    "new hampshire": "نيوهامشير",
    "new jersey": "نيوجيرسي",
    "new mexico": "نيومكسيكو",
    "north carolina": "كارولاينا الشمالية",
    "north dakota": "داكوتا الشمالية",
    "ohio": "أوهايو",
    "oklahoma": "أوكلاهوما",
    "oregon": "أوريغن",
    "pennsylvania": "بنسلفانيا",
    "rhode island": "رود آيلاند",
    "south carolina": "كارولاينا الجنوبية",
    "south dakota": "داكوتا الجنوبية",
    "tennessee": "تينيسي",
    "texas": "تكساس",
    "utah": "يوتا",
    "vermont": "فيرمونت",
    "virginia": "فرجينيا",
    "west virginia": "فرجينيا الغربية",
    "wisconsin": "ويسكونسن",
    "wyoming": "وايومنغ",
}

JAPAN_REGIONAL_LABELS = {
    "gokishichidō": "",
    "saitama": "سايتاما",
    "tohoku": "توهوكو",
    "shikoku": "شيكوكو",
    "kyushu": "كيوشو",
    "kantō": "كانتو",
    "kansai": "كانساي",
    "hokkaido": "هوكايدو",
    "hokuriku": "هوكوريكو",
    "chūgoku": "تشوغوكو",
    "toyama": "توياما",
    "tokushima": "توكوشيما",
    "chiba": "تشيبا",
    "tottori": "توتوري",
    "tochigi": "توتشيغي",
    "iwate": "إيواته",
    "ibaraki": "إيباراكي",
    "ishikawa": "إيشيكاوا",
    "ōsaka": "أوساكا",
    "okayama": "أوكاياما",
    "ehime": "إهيمه",
    "akita": "أكيتا",
    "aomori": "آوموري",
    "aichi": "آيتشي",
    "ōita": "أويتا",
    "okinawa": "أوكيناوا",
    "saga": "ساغا",
    "shimane": "شيمانه",
    "shiga": "شيغا",
    "shizuoka": "شيزوكا",
    "kanagawa": "كاناغاوا",
    "kagoshima": "كاغوشيما",
    "kagawa": "كاغاوا",
    "fukui": "فوكوي",
    "fukuoka": "فوكوكا",
    "fukushima": "فوكوشيما",
    "gifu": "غيفو",
    "gunma": "غونما",
    "kōchi": "كوتشي",
    "kumamoto": "كوماموتو",
    "kyōto": "كيوتو",
    "nagano": "ناغانو",
    "nagasaki": "ناغاساكي",
    "nara": "نارا",
    "mie": "ميه",
    "miyagi": "مياغي",
    "miyazaki": "ميازاكي",
    "yamanashi": "ياماناشي",
    "yamaguchi": "ياماغوتشي",
    "yamagata": "ياماغاتا",
    "wakayama": "واكاياما",
    "hyōgo": "هيوغو",
    "hiroshima prefecture": "عمالة هيروشيما",
    "niigata": "نييغاتا",
    "hokkaidō": "هوكايدو",
}

TURKEY_PROVINCE_LABELS = {
    "adana": "أضنة",
    "adıyaman": "أديامان",
    "afyonkarahisar": "أفيون قره حصار",
    "ağrı": "أغري",
    "aksaray": "آق سراي",
    "amasya": "أماصيا",
    "ankara": "أنقرة",
    "antalya": "أنطاليا",
    "ardahan": "أردهان",
    "artvin": "أرتوين",
    "aydın": "أيدين",
    "balıkesir": "بالق أسير",
    "bartın": "بارتين",
    "batman": "بطمان",
    "bayburt": "بايبورت",
    "bilecik": "بيله جك",
    "bingöl": "بينكل",
    "bitlis": "بتليس",
    "bolu": "بولو",
    "burdur": "بوردور",
    "bursa": "بورصة",
    "çanakkale": "جاناكالي",
    "çankırı": "جانقري",
    "çorum": "جوروم",
    "denizli": "دنيزلي",
    "diyarbakır": "دياربكر",
    "düzce": "دوزجه",
    "edirne": "أدرنة",
    "elazığ": "إلازيغ",
    "erzincan": "أرزينجان",
    "erzurum": "أرضروم",
    "eskişehir": "إسكيشهر",
    "gaziantep": "عنتاب",
    "giresun": "غيرسون",
    "gümüşhane": "كوموش خانة",
    "hakkâri": "حكاري",
    "hatay": "هاتاي",
    "iğdır": "اغدير",
    "isparta": "إسبرطة",
    "istanbul": "إسطنبول",
    "izmir": "إزمير",
    "kahramanmaraş": "قهرمان مرعش",
    "karabük": "كارابوك",
    "karaman": "كارامان",
    "kars": "كارس",
    "kastamonu": "قسطموني",
    "kayseri": "قيصري",
    "kilis": "كلس",
    "kırıkkale": "قيريقكالي",
    "kırklareli": "قرقلر ايلي",
    "kırşehir": "قرشهر",
    "kocaeli": "قوجه ايلي",
    "konya": "قونية",
    "kütahya": "كوتاهية",
    "malatya": "ملطية",
    "manisa": "مانيسا",
    "mardin": "ماردين",
    "mersin": "مرسين",
    "muğla": "موغلا",
    "muş": "موش",
    "nevşehir": "نوشهر",
    "niğde": "نيدا",
    "ordu": "أردو",
    "osmaniye": "عثمانية",
    "rize": "ريزه",
    "sakarya": "صقاريا",
    "samsun": "سامسون",
    "şanlıurfa": "شانلي أورفة",
    "siirt": "سعرد",
    "sinop": "سينوب",
    "sivas": "سيواس",
    "şırnak": "شرناق",
    "tekirdağ": "تكيرداغ",
    "tokat": "توقات",
    "trabzon": "طرابزون",
    "tunceli": "تونجلي",
    "uşak": "أوشاك",
    "van": "وان",
    "yalova": "يالوفا",
    "yozgat": "يوزغات",
    "zonguldak": "زانغولداك",
}


COMPANY_LABELS_NEW = {
    "airliner": "طائرات",
    "condiment": "توابل",
    "fraternal service": "خدمات أخوية",
    "health care": "رعاية صحية",
    "internet": "إنترنت",
    "magazine": "مجلات",
    "mass media": "وسائل إعلام",
    "military logistics": "لوجستية عسكرية",
    "rail": "سكك حديدية",
    "submarine": "غواصات",
}

JAPAN_LABELS = _make_japan_labels(JAPAN_REGIONAL_LABELS)
TURKEY_LABELS = _make_turkey_labels(TURKEY_PROVINCE_LABELS)


CITY_LABEL_PATCHES = load_json_mapping("cities/yy2.json")
COUNTRY_LABEL_OVERRIDES = load_json_mapping("geography/P17_2_final_ll.json")
raw_region_overrides = load_json_mapping("geography/popopo.json")


"""
NEW_P17_FINAL = _build_country_label_index(  # 68,981
    CITY_TRANSLATIONS_LOWER,
    all_country_ar,
    US_STATES,
    COUNTRY_LABEL_OVERRIDES,
    COUNTRY_ADMIN_LABELS,
    MAIN_REGION_TRANSLATIONS,
    raw_region_overrides,
    SECONDARY_REGION_TRANSLATIONS,
    INDIA_REGION_TRANSLATIONS,
    TAXON_TABLE,
    BASE_POP_FINAL_5,
)
"""

ALIASES_CHAIN = {
    "COMPANY_LABELS_NEW": COMPANY_LABELS_NEW,
    "TURKEY_LABELS": TURKEY_LABELS,
    "JAPAN_LABELS": JAPAN_LABELS,
    "CITY_LABEL_PATCHES": CITY_LABEL_PATCHES,
}

__all__ = [
    "_build_country_label_index",
    "ALIASES_CHAIN",
    "COUNTRY_LABEL_OVERRIDES",
    "US_STATES",
    "raw_region_overrides",
    # "NEW_P17_FINAL",
]

len_print.data_len(
    "labels_country.py",
    {
        "COUNTRY_LABEL_OVERRIDES": COUNTRY_LABEL_OVERRIDES,
        "CITY_LABEL_PATCHES": CITY_LABEL_PATCHES,  # 5,191
        # "NEW_P17_FINAL": NEW_P17_FINAL,
    },
)



"""
Population and people helpers.
"""

from __future__ import annotations

import functools
import logging

from ..translations.funcs import open_json_file
from ..translations_formats import FormatData

logger = logging.getLogger(__name__)

people_dictionary = open_json_file("people/peoples.json") or {}

formatted_data = {
    "by {person_key}": "بواسطة {person_label}",
    # Category:Relationships_of_Jeffrey_Epstein
    "relationships of {person_key}": "علاقات {person_label}",
    "{person_key} administration cabinet members": "أعضاء مجلس وزراء إدارة {person_label}",
    "{person_key} administration personnel": "موظفو إدارة {person_label}",
    "{person_key} executive office": "مكتب {person_label} التنفيذي",
    "{person_key} memorials": "نصب {person_label} التذكارية",
    "{person_key} cabinet": "مجلس وزراء {person_label}",
    "{person_key} albums": "ألبومات {person_label}",
    "{person_key} animation albums": "ألبومات رسوم متحركة {person_label}",
    "{person_key} comedy albums": "ألبومات كوميدية {person_label}",
    "{person_key} compilation albums": "ألبومات تجميعية {person_label}",
    "{person_key} concept albums": "ألبومات مفاهيمية {person_label}",
    "{person_key} eps albums": "ألبومات أسطوانة مطولة {person_label}",
    "{person_key} folk albums": "ألبومات فولك {person_label}",
    "{person_key} folktronica albums": "ألبومات فولكترونيكا {person_label}",
    "{person_key} jazz albums": "ألبومات جاز {person_label}",
    "{person_key} live albums": "ألبومات مباشرة {person_label}",
    "{person_key} mixtape albums": "ألبومات ميكستايب {person_label}",
    "{person_key} remix albums": "ألبومات ريمكس {person_label}",
    "{person_key} surprise albums": "ألبومات مفاجئة {person_label}",
    "{person_key} video albums": "ألبومات فيديو {person_label}",
}


def _load_bot() -> FormatData:
    _peoples_bot = FormatData(
        formatted_data=formatted_data,
        data_list=people_dictionary,
        key_placeholder="{person_key}",
        value_placeholder="{person_label}",
    )

    return _peoples_bot


@functools.lru_cache(maxsize=2048)
def work_peoples(name: str) -> str:
    """
    Return the label for ``name`` using FormatData.
    """
    logger.debug(f"<<yellow>> {name=}")

    if label := people_dictionary.get(name):
        logger.info(f"<<yellow>> end direct hit {name=}, {label=}")
        return label

    _peoples_bot = _load_bot()

    resolved_label = _peoples_bot.search(name)

    logger.info(f"<<yellow>> end {name=}, {resolved_label=}")
    return resolved_label


__all__ = [
    "work_peoples",
]



"""Tests for build_labels_country.py country label aggregation utilities."""

from collections.abc import MutableMapping

from ArWikiCats.translations.data_builders.build_labels_country import (
    _build_country_label_index,
    _handle_the_prefix,
    _make_japan_labels,
    _make_turkey_labels,
    setdefault_with_lowercased,
    update_with_lowercased,
)


class TestUpdateWithLowercased:
    """Tests for update_with_lowercased function."""

    def test_update_lowercases_keys(self) -> None:
        target: MutableMapping[str, str] = {}
        mapping = {"Cairo": "القاهرة", "London": "لندن"}

        update_with_lowercased(target, mapping)

        assert target["cairo"] == "القاهرة"
        assert target["london"] == "لندن"

    def test_update_skips_empty_values(self) -> None:
        target: MutableMapping[str, str] = {"existing": "موجود"}
        mapping = {"New": "", "Value": "قيمة"}

        update_with_lowercased(target, mapping)

        assert "new" not in target
        assert target["value"] == "قيمة"

    def test_update_overwrites_existing(self) -> None:
        target: MutableMapping[str, str] = {"key": "قديم"}
        mapping = {"Key": "جديد"}

        update_with_lowercased(target, mapping)

        assert target["key"] == "جديد"


class TestSetdefaultWithLowercased:
    """Tests for setdefault_with_lowercased function."""

    def test_setdefault_adds_missing_keys(self) -> None:
        target: MutableMapping[str, str] = {}
        mapping = {"Key": "قيمة"}

        setdefault_with_lowercased(target, mapping)

        assert target["key"] == "قيمة"

    def test_setdefault_skips_existing_keys(self) -> None:
        target: MutableMapping[str, str] = {"key": "_original"}
        mapping = {"Key": "جديد"}

        setdefault_with_lowercased(target, mapping)

        assert target["key"] == "_original"

    def test_setdefault_skips_empty_values(self) -> None:
        target: MutableMapping[str, str] = {}
        mapping = {"Empty": "", "Value": "قيمة"}

        setdefault_with_lowercased(target, mapping)

        assert "empty" not in target
        assert target["value"] == "قيمة"


class TestMakeJapanLabels:
    """Tests for _make_japan_labels function."""

    def test_creates_base_labels(self) -> None:
        data = {"Tokyo": "طوكيو", "Osaka": "أوساكا"}
        result = _make_japan_labels(data)

        assert result["tokyo"] == "طوكيو"
        assert result["osaka"] == "أوساكا"

    def test_creates_prefecture_variants(self) -> None:
        data = {"Hokkaido": "هوكايدو"}
        result = _make_japan_labels(data)

        assert result["hokkaido prefecture"] == "محافظة هوكايدو"

    def test_creates_region_variants(self) -> None:
        data = {"Kyoto": "كيوتو"}
        result = _make_japan_labels(data)

        assert result["kyoto region"] == "منطقة كيوتو"

    def test_skips_empty_labels(self) -> None:
        data = {"Valid": "صحيح", "Empty": ""}
        result = _make_japan_labels(data)

        assert "valid" in result
        assert "valid prefecture" in result
        assert "empty" not in result


class TestMakeTurkeyLabels:
    """Tests for _make_turkey_labels function."""

    def test_creates_base_labels(self) -> None:
        data = {"Istanbul": "إسطنبول", "Ankara": "أنقرة"}
        result = _make_turkey_labels(data)

        assert result["istanbul"] == "إسطنبول"
        assert result["ankara"] == "أنقرة"

    def test_creates_province_variants(self) -> None:
        data = {"Izmir": "إزمير"}
        result = _make_turkey_labels(data)

        assert result["izmir province"] == "محافظة إزمير"

    def test_creates_districts_variants(self) -> None:
        data = {"Bursa": "بورصة"}
        result = _make_turkey_labels(data)

        assert result["districts of bursa province"] == "أقضية محافظة بورصة"

    def test_skips_empty_labels(self) -> None:
        data = {"Valid": "صحيح", "Empty": ""}
        result = _make_turkey_labels(data)

        assert "valid" in result
        assert "valid province" in result
        assert "empty" not in result


class TestHandleThePrefix:
    """Tests for _handle_the_prefix function."""

    def test_creates_entries_without_the(self) -> None:
        label_index = {"the gambia": "غامبيا", "egypt": "مصر"}
        result = _handle_the_prefix(label_index)

        assert "gambia" in result
        assert result["gambia"] == "غامبيا"

    def test_skips_if_trimmed_key_exists(self) -> None:
        label_index = {"the netherlands": "هولندا", "netherlands": "هولندا"}
        result = _handle_the_prefix(label_index)

        assert "netherlands" not in result  # already exists

    def test_case_insensitive_matching(self) -> None:
        label_index = {"The Gambia": "غامبيا"}
        result = _handle_the_prefix(label_index)

        # The function preserves the original case after removing "the "
        assert "Gambia" in result

    def test_skips_empty_values(self) -> None:
        label_index = {"the empty": "", "valid": "صحيح"}
        result = _handle_the_prefix(label_index)

        assert "empty" not in result


class TestBuildCountryLabelIndex:
    """Tests for _build_country_label_index function."""

    def test_merges_all_sources(self) -> None:
        CITY_TRANSLATIONS_LOWER = {"cairo": "القاهرة"}
        all_country_ar = {"egypt": "مصر"}
        US_STATES = {}
        COUNTRY_LABEL_OVERRIDES = {}
        COUNTRY_ADMIN_LABELS = {}
        MAIN_REGION_TRANSLATIONS = {}
        raw_region_overrides = {}
        SECONDARY_REGION_TRANSLATIONS = {}
        INDIA_REGION_TRANSLATIONS = {}
        TAXON_TABLE = {}
        BASE_POP_FINAL_5 = {}

        result = _build_country_label_index(
            CITY_TRANSLATIONS_LOWER,
            all_country_ar,
            US_STATES,
            COUNTRY_LABEL_OVERRIDES,
            COUNTRY_ADMIN_LABELS,
            MAIN_REGION_TRANSLATIONS,
            raw_region_overrides,
            SECONDARY_REGION_TRANSLATIONS,
            INDIA_REGION_TRANSLATIONS,
            TAXON_TABLE,
            BASE_POP_FINAL_5,
        )

        assert "cairo" in result
        assert result["cairo"] == "القاهرة"

    def test_adds_specific_overrides(self) -> None:
        # Minimal setup for testing specific overrides
        result = _build_country_label_index(
            CITY_TRANSLATIONS_LOWER={},
            all_country_ar={},
            US_STATES={},
            COUNTRY_LABEL_OVERRIDES={},
            COUNTRY_ADMIN_LABELS={},
            MAIN_REGION_TRANSLATIONS={},
            raw_region_overrides={},
            SECONDARY_REGION_TRANSLATIONS={},
            INDIA_REGION_TRANSLATIONS={},
            TAXON_TABLE={},
            BASE_POP_FINAL_5={},
        )

        assert "indycar" in result
        assert result["indycar"] == "أندي كار"
        assert "motorsport" in result

    def test_adds_setdefault_entries(self) -> None:
        # Test that setdefault_with_lowercased is called for fallback tables
        CITY_TRANSLATIONS_LOWER = {}
        all_country_ar = {}
        US_STATES = {}
        COUNTRY_LABEL_OVERRIDES = {}
        COUNTRY_ADMIN_LABELS = {}
        MAIN_REGION_TRANSLATIONS = {}
        raw_region_overrides = {}
        SECONDARY_REGION_TRANSLATIONS = {}
        INDIA_REGION_TRANSLATIONS = {}
        TAXON_TABLE = {"taxon_key": "قيمة"}
        BASE_POP_FINAL_5 = {"pop_key": "سكان"}

        result = _build_country_label_index(
            CITY_TRANSLATIONS_LOWER,
            all_country_ar,
            US_STATES,
            COUNTRY_LABEL_OVERRIDES,
            COUNTRY_ADMIN_LABELS,
            MAIN_REGION_TRANSLATIONS,
            raw_region_overrides,
            SECONDARY_REGION_TRANSLATIONS,
            INDIA_REGION_TRANSLATIONS,
            TAXON_TABLE,
            BASE_POP_FINAL_5,
        )

        # These should be added via setdefault (not overwriting existing)
        assert result["taxon_key"] == "قيمة"
        assert result["pop_key"] == "سكان"



#!/usr/bin/python3
""" """

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.countries_names_and_sports import (
    resolve_countries_names_sport_with_ends,
)
from ArWikiCats.new_resolvers.sports_resolvers.nationalities_and_sports import resolve_nats_sport_multi_v2
from ArWikiCats.new_resolvers.sports_resolvers.raw_sports import (
    resolve_sport_label_unified,
)
from ArWikiCats.new_resolvers.sports_resolvers.raw_sports_with_suffixes import wrap_team_xo_normal_2025_with_ends
from ArWikiCats.new_resolvers.sports_resolvers.sport_lab_nat import sport_lab_nat_load_new

data_0 = {
    "Association football cup competitions": "منافسات كأس كرة القدم",
    "Football cup competitions in United Arab Emirates": "منافسات كأس كرة القدم في الإمارات العربية المتحدة",
    "Managers of baseball teams in Japan": "مدربو فرق كرة قاعدة في اليابان",
    "Men's football cup competitions in France": "منافسات كأس كرة القدم رجالية في فرنسا",
    "Men's football cup competitions in Scotland": "منافسات كأس كرة القدم رجالية في إسكتلندا",
    "beach volleyball racing teams": "فرق سباق كرة الطائرة الشاطئية",
    "football teams": "فرق كرة القدم",
    "canadian-football teams": "فرق كرة القدم الكندية",
    "trampolining teams": "فرق جمباز القفز",
    "tennis racing teams": "فرق سباق كرة المضرب",
    "javelin throw racing teams": "فرق سباق رمي الرمح",
    "freestyle wrestling teams": "فرق المصارعة الحرة",
    "beach soccer racing teams": "فرق سباق كرة القدم الشاطئية",
    "ice sledge hockey teams": "فرق هوكي المزلجة على الجليد",
    "motorboat teams": "فرق الزوارق النارية",
    "long jump teams": "فرق القفز الطويل",
    "beach handball racing teams": "فرق سباق كرة اليد الشاطئية",
}

resolve_team_suffix_test_data = {
    "short track speed skating cup": "كأس التزلج على مسار قصير",
    "wheelchair basketball cup": "كأس كرة السلة على الكراسي المتحركة",
    "luge cup": "كأس الزحف الثلجي",
    "motorsports racing cup": "كأس سباق رياضة المحركات",
    "speed skating cup": "كأس التزلج السريع",
    "roller hockey (quad) cup": "كأس هوكي الدحرجة",
    "association football cup": "كأس كرة القدم",
    "kick boxing racing cup": "كأس سباق الكيك بوكسينغ",
    "shot put racing cup": "كأس سباق دفع الثقل",
    "luge racing cup": "كأس سباق الزحف الثلجي",
    "water skiing cup": "كأس التزلج على الماء",
    "motocross cup": "كأس موتو كروس",
    "pencak silat cup": "كأس بنكات سيلات",
    "pesäpallo cup": "كأس بيسبالو",
    "fifa world cup racing records and statistics": "سجلات وإحصائيات سباق كأس العالم لكرة القدم",
    "davis cup racing music": "موسيقى سباق كأس ديفيز",
    "davis cup racing songs": "أغاني سباق كأس ديفيز",
    "polo cup playoffs": "تصفيات كأس بولو",
    "fifa world cup films": "أفلام كأس العالم لكرة القدم",
    "fifa futsal world cup racing manager history": "تاريخ مدربو سباق كأس العالم لكرة الصالات",
    "dragon boat cup playoffs": "تصفيات كأس سباق قوارب التنين",
    "fifa world cup racing chairmen and investors": "رؤساء ومسيرو سباق كأس العالم لكرة القدم",
    "road bicycle racing cup playoffs": "تصفيات كأس سباق دراجات على الطريق",
    "fifa world cup umpires": "حكام كأس العالم لكرة القدم",
    "fifa futsal world cup racing leagues seasons": "مواسم دوريات سباق كأس العالم لكرة الصالات",
    "davis cup tactics and skills": "مهارات كأس ديفيز",
    "formula racing cup playoffs": "تصفيات كأس سباقات فورمولا",
    "fifa world cup racing non-profit organizations": "منظمات غير ربحية سباق كأس العالم لكرة القدم",
    "long jump cup playoffs": "تصفيات كأس قفز طويل",
    "freestyle wrestling cup playoffs": "تصفيات كأس مصارعة حرة",
    "pair skating cup playoffs": "تصفيات كأس تزلج فني على الجليد",
    "beach handball cup playoffs": "تصفيات كأس كرة يد شاطئية",
    "darts cup playoffs": "تصفيات كأس سهام مريشة",
    "fifa futsal world cup racing terminology": "مصطلحات سباق كأس العالم لكرة الصالات",
    "rifle shooting cup playoffs": "تصفيات كأس رماية بندقية",
    "bullfighting cup playoffs": "تصفيات كأس مصارعة ثيران",
    "water polo cup playoffs": "تصفيات كأس كرة ماء",
    "roller skating racing cups": "كؤوس سباق تزلج بالعجلات",
    "dragon boat racing cups": "كؤوس سباق قوارب التنين",
    "racingxx cups": "كؤوس سباق سيارات",
    "silat cups": "كؤوس سيلات",
    "rugby league racing cups": "كؤوس سباق دوري رجبي",
    "speed skating racing cups": "كؤوس سباق تزلج سريع",
    "goalball racing cups": "كؤوس سباق كرة هدف",
    "boxing cups": "كؤوس بوكسينغ",
    "roller hockey cups": "كؤوس هوكي دحرجة",
    "bandy cups": "كؤوس باندي",
    "high jump racing cups": "كؤوس سباق قفز عالي",
    "powerlifting cups": "كؤوس رياضة قوة",
    "bowling cups": "كؤوس بولينج",
    "table tennis cups": "كؤوس كرة طاولة",
    "racquets racing cups": "كؤوس سباق لعبة الراح",
    "yacht racing cups": "كؤوس سباقات يخوت",
}

test_2025 = {
    # "sports cup competitions": "منافسات كؤوس رياضية",
    "defunct football cups": "كؤوس كرة قدم سابقة",
    "domestic football cups": "كؤوس كرة قدم محلية",
    "football cups": "كؤوس كرة قدم",
    "professional football cups": "كؤوس كرة قدم للمحترفين",
    "motorcycle racing cups": "كؤوس سباق دراجات نارية",
    "domestic football cup": "",  # "كؤوس كرة قدم محلية",
    "defunct football cup competitions": "",  # "منافسات كؤوس كرة قدم سابقة",
    "defunct rugby union cup competitions": "",  # "منافسات كؤوس اتحاد رجبي سابقة",
    "basketball cup competitions": "منافسات كأس كرة السلة",
    "football cup competitions": "منافسات كأس كرة القدم",
    "soccer cup competitions": "منافسات كأس كرة القدم",
    "motorcycle racing cup": "كأس سباق الدراجات النارية",
}

sport_lab2_test_data = {
    "defunct indoor boxing": "بوكسينغ داخل الصالات سابقة",
    "defunct indoor boxing clubs": "أندية بوكسينغ داخل الصالات سابقة",
    "defunct indoor boxing cups": "كؤوس بوكسينغ داخل الصالات سابقة",
    "defunct football cup competitions": "منافسات كؤوس كرة قدم سابقة",
    "defunct football cups": "كؤوس كرة قدم سابقة",
    "professional football cups": "كؤوس كرة قدم للمحترفين",
    "domestic football cup": "كؤوس كرة قدم محلية",
    "domestic football cups": "كؤوس كرة قدم محلية",
    "football cup competitions": "منافسات كؤوس كرة قدم",
    "football cups": "كؤوس كرة قدم",
    "basketball cup competitions": "منافسات كؤوس كرة سلة",
    "field hockey cup competitions": "منافسات كؤوس هوكي ميدان",
    "baseball world cup": "كأس العالم لكرة القاعدة",
    "biathlon world cup": "كأس العالم للبياثلون",
    "cricket world cup": "كأس العالم للكريكت",
    "curling world cup": "كأس العالم للكيرلنغ",
    "esports world cup": "كأس العالم للرياضة الإلكترونية",
    "hockey world cup": "كأس العالم للهوكي",
    "men's hockey world cup": "كأس العالم للهوكي للرجال",
    "men's rugby world cup": "كأس العالم للرجبي للرجال",
    "men's softball world cup": "كأس العالم للكرة اللينة للرجال",
    "netball world cup": "كأس العالم لكرة الشبكة",
    "rugby league world cup": "كأس العالم لدوري الرجبي",
    "rugby world cup": "كأس العالم للرجبي",
    "wheelchair rugby league world cup": "كأس العالم لدوري الرجبي على الكراسي المتحركة",
    "wheelchair rugby world cup": "كأس العالم للرجبي على الكراسي المتحركة",
    "women's cricket world cup ": "كأس العالم للكريكت للسيدات",
    "women's cricket world cup tournaments": "بطولات كأس العالم للكريكت للسيدات",
    "women's cricket world cup": "كأس العالم للكريكت للسيدات",
    "women's field hockey world cup": "كأس العالم لهوكي الميدان للسيدات",
    "women's hockey world cup": "كأس العالم للهوكي للسيدات",
    "women's rugby league world cup": "كأس العالم لدوري الرجبي للسيدات",
    "women's rugby world cup": "كأس العالم للرجبي للسيدات",
    "women's softball world cup": "كأس العالم للكرة اللينة للسيدات",
    "wrestling world cup": "كأس العالم للمصارعة",
}

nats_sport_multi_v2_data = {
    "yemeni mens basketball cup": "كأس اليمن لكرة السلة للرجال",
    "yemeni womens basketball cup": "كأس اليمن لكرة السلة للسيدات",
    "yemeni basketball cup": "كأس اليمن لكرة السلة",
    "yemeni defunct basketball cup": "كؤوس كرة سلة يمنية سابقة",
    "chinese domestic boxing cup": "كؤوس بوكسينغ صينية محلية",
    "chinese boxing cup": "كأس الصين للبوكسينغ",
    "chinese boxing cup competitions": "منافسات كأس الصين للبوكسينغ",
    "chinese defunct boxing cup competitions": "منافسات كؤوس بوكسينغ صينية سابقة",
    "chinese defunct indoor boxing cups": "كؤوس بوكسينغ صينية داخل الصالات سابقة",
    "chinese defunct boxing cups": "كؤوس بوكسينغ صينية سابقة",
    "chinese defunct outdoor boxing cups": "كؤوس بوكسينغ صينية في الهواء الطلق سابقة",
    "chinese professional boxing cups": "كؤوس بوكسينغ صينية للمحترفين",
    "chinese indoor boxing cups": "كؤوس بوكسينغ صينية داخل الصالات",
    "chinese outdoor boxing cups": "كؤوس بوكسينغ صينية في الهواء الطلق",
    "chinese domestic boxing cups": "كؤوس بوكسينغ صينية محلية",
    "chinese domestic women's boxing cups": "كؤوس بوكسينغ صينية محلية للسيدات",
    "chinese boxing cups": "كؤوس بوكسينغ صينية",
}

sport_lab_nat_load_new_data = {
    "asian domestic football cups": "كؤوس كرة قدم آسيوية محلية",
    "austrian football cups": "كؤوس كرة قدم نمساوية",
    "belgian football cups": "كؤوس كرة قدم بلجيكية",
    "dutch football cups": "كؤوس كرة قدم هولندية",
    "english football cups": "كؤوس كرة قدم إنجليزية",
    "european domestic football cups": "كؤوس كرة قدم أوروبية محلية",
    "german football cups": "كؤوس كرة قدم ألمانية",
    "irish football cups": "كؤوس كرة قدم أيرلندية",
    "italian football cups": "كؤوس كرة قدم إيطالية",
    "north american domestic football cups": "كؤوس كرة قدم أمريكية شمالية محلية",
    "oceanian domestic football cups": "كؤوس كرة قدم أوقيانوسية محلية",
    "republic-of ireland football cups": "كؤوس كرة قدم أيرلندية",
    "scottish football cups": "كؤوس كرة قدم إسكتلندية",
    "spanish basketball cups": "كؤوس كرة سلة إسبانية",
    "spanish football cups": "كؤوس كرة قدم إسبانية",
    "thai football cups": "كؤوس كرة قدم تايلندية",
    "welsh football cups": "كؤوس كرة قدم ويلزية",
}

rcn_sport_with_ends_data = {
    "new zealand amateur kick boxing cup": "كأس نيوزيلندا للكيك بوكسينغ للهواة",
    "new zealand youth kick boxing cup": "كأس نيوزيلندا للكيك بوكسينغ للشباب",
    "new zealand men's kick boxing cup": "كأس نيوزيلندا للكيك بوكسينغ للرجال",
    "new zealand women's kick boxing cup": "كأس نيوزيلندا للكيك بوكسينغ للسيدات",
    "new zealand kick boxing cup": "كأس نيوزيلندا للكيك بوكسينغ",
    "yemen amateur kick boxing cup": "كأس اليمن للكيك بوكسينغ للهواة",
    "yemen youth kick boxing cup": "كأس اليمن للكيك بوكسينغ للشباب",
    "yemen men's kick boxing cup": "كأس اليمن للكيك بوكسينغ للرجال",
    "yemen women's kick boxing cup": "كأس اليمن للكيك بوكسينغ للسيدات",
    "yemen kick boxing cup": "كأس اليمن للكيك بوكسينغ",
}

to_test = [
    ("test_sport_lab2_data", sport_lab2_test_data, wrap_team_xo_normal_2025_with_ends),
    ("test_resolve_nats_sport_multi_v2", nats_sport_multi_v2_data, resolve_nats_sport_multi_v2),
    ("test_sport_lab_nat_load_new", sport_lab_nat_load_new_data, sport_lab_nat_load_new),
    ("test_rcn_sport_with_ends", rcn_sport_with_ends_data, resolve_countries_names_sport_with_ends),
    # ---
    ("test_test_sport_cup_1", sport_lab2_test_data, resolve_nats_sport_multi_v2),
    ("test_test_sport_cup_2", sport_lab2_test_data, sport_lab_nat_load_new),
    ("test_test_sport_cup_3", sport_lab2_test_data, resolve_countries_names_sport_with_ends),
    ("test_resolve_sport_label_unified", resolve_team_suffix_test_data, resolve_sport_label_unified),
    # ---
]


@pytest.mark.parametrize(
    "category, expected", resolve_team_suffix_test_data.items(), ids=resolve_team_suffix_test_data.keys()
)
@pytest.mark.fast
def test_resolve_team_suffix(category: str, expected: str) -> None:
    label1 = resolve_sport_label_unified(category)
    assert label1 == expected


@pytest.mark.parametrize("category, expected", test_2025.items(), ids=test_2025.keys())
@pytest.mark.fast
def test_wrap_team_xo_normal_2025(category: str, expected: str) -> None:
    label1 = wrap_team_xo_normal_2025_with_ends(category)
    assert label1 == expected


@pytest.mark.parametrize("category, expected", nats_sport_multi_v2_data.items(), ids=nats_sport_multi_v2_data.keys())
@pytest.mark.skip2
def test_resolve_nats_sport_multi_v2(category: str, expected: str) -> None:
    label1 = resolve_nats_sport_multi_v2(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize("category, expected", sport_lab2_test_data.items(), ids=sport_lab2_test_data.keys())
@pytest.mark.skip2
def test_sport_lab2_data(category: str, expected: str) -> None:
    label1 = wrap_team_xo_normal_2025_with_ends(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize(
    "category, expected", sport_lab_nat_load_new_data.items(), ids=sport_lab_nat_load_new_data.keys()
)
@pytest.mark.skip2
def test_sport_lab_nat_load_new(category: str, expected: str) -> None:
    label1 = sport_lab_nat_load_new(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize("category, expected", rcn_sport_with_ends_data.items(), ids=rcn_sport_with_ends_data.keys())
@pytest.mark.skip2
def test_rcn_sport_with_ends(category: str, expected: str) -> None:
    label1 = resolve_countries_names_sport_with_ends(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.skip2
def test_dump_it(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)

    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""
Nationality system with full refactoring and full type hints.
All comments are in English only.
"""

from __future__ import annotations

from typing import Any, Dict

from ..data_builders.build_nationalities import (
    NationalityEntry,
    build_american_forms,
    build_lookup_tables,
    load_sources,
    normalize_aliases,
)
from ..helps import len_print
from ..utils import open_json_file

AllNatDict = Dict[str, NationalityEntry]
LookupTable = Dict[str, str]


# =====================================================================
# Type aliases
# =====================================================================

countries_en_as_nationality_keys = [
    "antigua and barbuda",
    "botswana",
    "central african republic",
    "chinese taipei",
    "democratic republic of congo",
    "democratic-republic-of-congo",
    "dominican republic",
    "federated states of micronesia",
    "federated states-of micronesia",
    "georgia (country)",
    "hong kong",
    "ireland",
    "kiribati",
    "kyrgyz",
    "lesotho",
    "liechtenstein",
    "new zealand",
    "northern ireland",
    "republic of congo",
    "republic of ireland",
    "republic-of ireland",
    "republic-of-congo",
    "são toméan",
    "trinidad and tobago",
    "turkmen",
    "turkmenistan",
    "uzbek",
    "vatican",
    "west india",
]


raw_sub_nat_additional_to_check = {
    "muslims": {
        "male": "مسلم",
        "males": "مسلمون",
        "female": "مسلمة",
        "females": "مسلمات",
        "the_male": "المسلم",
        "the_female": "المسلمة",
        "en": "",
        "ar": "الإسلام",
    },
    "muslim": {
        "male": "مسلم",
        "males": "مسلمون",
        "female": "مسلمة",
        "females": "مسلمات",
        "the_male": "المسلم",
        "the_female": "المسلمة",
        "en": "muslims",
        "ar": "الإسلام",
    },
}

raw_sub_nat_additional = {
    "jews": {
        "male": "يهودي",
        "males": "يهود",
        "female": "يهودية",
        "females": "يهوديات",
        "the_male": "اليهودي",
        "the_female": "اليهودية",
        "en": "",
        "ar": "اليهودية",
    },
    "sufi": {
        "male": "صوفي",
        "males": "صوفيون",
        "female": "صوفية",
        "females": "صوفيات",
        "the_male": "الصوفي",
        "the_female": "الصوفية",
        "en": "",
        "ar": "الصوفية",
    },
    "christian": {
        "male": "مسيحي",
        "males": "مسيحيون",
        "female": "مسيحية",
        "females": "مسيحيات",
        "the_male": "المسيحي",
        "the_female": "المسيحية",
        "en": "",
        "ar": "المسيحية",
    },
}


# =====================================================================
# Main Execution (same logic as before)
# =====================================================================

raw_nats_as_en_key: Dict[str, Any] = open_json_file("nationalities/all_nat_as_en.json") or {}

raw_all_nat_o: AllNatDict = open_json_file("nationalities/nationalities_data.json") or {}
nat_directions_mapping: AllNatDict = open_json_file("nationalities/nationalities_data_with_directions.json") or {}

raw_uu_nats: AllNatDict = open_json_file("nationalities/sub_nats_with_ar_or_en.json") or {}
raw_sub_nat: AllNatDict = open_json_file("nationalities/sub_nats.json") or {}
continents: AllNatDict = open_json_file("nationalities/continents.json") or {}

nationalities_data: Dict[str, NationalityEntry] = load_sources(
    raw_all_nat_o,
    nat_directions_mapping,
    raw_uu_nats,
    raw_sub_nat,
    continents,
    raw_sub_nat_additional,
    countries_en_as_nationality_keys,
    raw_nats_as_en_key,
)


nationalities_data = normalize_aliases(nationalities_data, True)

All_Nat: AllNatDict = {k.lower(): v for k, v in nationalities_data.items()}

American_nat = build_american_forms(nationalities_data)
# All_Nat.update(American_nat)

result_tables = build_lookup_tables(All_Nat)

Nat_men: LookupTable = result_tables["Nat_men"]
Nat_mens: LookupTable = result_tables["Nat_mens"]
Nat_women: LookupTable = result_tables["Nat_women"]
Nat_Womens: LookupTable = result_tables["Nat_Womens"]

Nat_the_male: LookupTable = result_tables["Nat_the_male"]
Nat_the_female: LookupTable = result_tables["Nat_the_female"]

ar_Nat_men: LookupTable = result_tables["ar_Nat_men"]
countries_from_nat: LookupTable = result_tables["countries_from_nat"]
all_country_ar: LookupTable = result_tables["all_country_ar"]

all_country_with_nat: AllNatDict = result_tables["all_country_with_nat"]
all_country_with_nat_ar: AllNatDict = result_tables["all_country_with_nat_ar"]
countries_nat_en_key: Dict[str, NationalityEntry] = result_tables["countries_nat_en_key"]

en_nats_to_ar_label: LookupTable = result_tables["en_nats_to_ar_label"]

all_nat_sorted = dict(
    sorted(
        All_Nat.items(),
        key=lambda k: (-k[0].count(" "), -len(k[0])),
    )
)

len_result = {
    "raw_nats_as_en_key": 17,
    "ar_Nat_men": 711,
    "Nat_men": 841,
    "Nat_mens": 843,
    "Nat_women": 843,
    "Nat_Womens": 843,
    "All_Nat": 843,
    "Nat_the_male": 843,
    "Nat_the_female": 843,
    "all_country_ar": 285,
    "countries_from_nat": 287,
    "all_country_with_nat_ar": 342,
    "en_nats_to_ar_label": 342,
    "all_country_with_nat": 336,
    "American_nat": 422,
    "countries_nat_en_key": 286,
}
len_print.data_len(
    "nationality.py",
    {
        "raw_nats_as_en_key": raw_nats_as_en_key,
        "ar_Nat_men": ar_Nat_men,
        "Nat_men": Nat_men,
        "Nat_mens": Nat_mens,
        "Nat_women": Nat_women,
        "Nat_Womens": Nat_Womens,
        "all_country_ar": all_country_ar,
        "countries_from_nat": countries_from_nat,
        "All_Nat": All_Nat,
        "all_country_with_nat_ar": all_country_with_nat_ar,
        "all_country_with_nat": all_country_with_nat,
        "American_nat": American_nat,
        "countries_nat_en_key": countries_nat_en_key,
        "en_nats_to_ar_label": en_nats_to_ar_label,
        "Nat_the_male": Nat_the_male,
        "Nat_the_female": Nat_the_female,
    },
)



""" """

from __future__ import annotations

import pytest

from ArWikiCats import resolve_label_ar

data_1 = {
    "Adaptations of works by Albanian writers": "أعمال مقتبسة عن أعمال كتاب ألبان",
    "Adaptations of works by Estonian writers": "أعمال مقتبسة عن أعمال كتاب إستونيون",
    "Adaptations of works by Greek writers": "أعمال مقتبسة عن أعمال كتاب يونانيون",
    "Adaptations of works by Irish writers": "أعمال مقتبسة عن أعمال كتاب أيرلنديون",
    "Adaptations of works by Italian writers": "أعمال مقتبسة عن أعمال كتاب إيطاليون",
    "Alternative rock albums by American artists": "ألبومات روك بديل بواسطة فنانون أمريكيون",
    "Alternative rock albums by Bosnia and Herzegovina artists": "ألبومات روك بديل بواسطة فنانون بوسنيون",
    "Black metal albums by Singaporean artists": "ألبومات بلاك ميتال بواسطة فنانون سنغافوريون",
    "Christian music albums by South African artists": "ألبومات موسيقى مسيحية بواسطة فنانون جنوب إفريقيون",
    "Christian rock albums by South African artists": "ألبومات روك مسيحي بواسطة فنانون جنوب إفريقيون",
    "Compilation albums by Spanish artists": "ألبومات تجميعية بواسطة فنانون إسبان",
    "Dance music albums by Hong Kong artists": "ألبومات موسيقى الرقص بواسطة فنانون هونغ كونغيون",
    "Dance music albums by Swiss artists": "ألبومات موسيقى الرقص بواسطة فنانون سويسريون",
    "Electronic albums by Iranian artists": "ألبومات إليكترونيك بواسطة فنانون إيرانيون",
    "Films by South African directors": "أفلام مخرجون جنوب إفريقيون",
    "Films by South African producers": "أفلام منتجون جنوب إفريقيون",
    "Funk albums by Danish artists": "ألبومات فانك بواسطة فنانون دنماركيون",
    "Hardcore punk albums by British artists": "ألبومات هاردكور بانك بواسطة فنانون بريطانيون",
    "Indie rock albums by Danish artists": "ألبومات إيندي روك بواسطة فنانون دنماركيون",
    "Indie rock albums by Manx artists": "ألبومات إيندي روك بواسطة فنانون مانكسيون",
    "Indie rock albums by South African artists": "ألبومات إيندي روك بواسطة فنانون جنوب إفريقيون",
    "Pop albums by Czech artists": "ألبومات بوب بواسطة فنانون تشيكيون",
    "Prisoners sentenced to death by Papua New Guinea": "مسجونون حكم عليهم بالإعدام بواسطة بابوا غينيا الجديدة",
    "Synth-pop albums by Danish artists": "ألبومات سينثبوب بواسطة فنانون دنماركيون",
    "Thrash metal albums by English artists": "ألبومات ثراش ميتال بواسطة فنانون إنجليز",
    "Video albums by Welsh artists": "ألبومات فيديو بواسطة فنانون ويلزيون",
    "Works by British classical composers": "أعمال ملحنون كلاسيكيون بريطانيون",
}


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_by_people_or_job(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected



"""
Unit tests for country_resolver module.
"""

import pytest

from ArWikiCats.legacy_bots.resolvers.country_resolver import (
    CountryLabelRetriever,
    Get_country2,
    _get_fallback_label,
    _validate_separators,
    check_historical_prefixes,
    event2_d2,
    fetch_country_term_label,
    get_country_label,
    set_fallback_resolver,
)

# ---------------------------------------------------------------------------
# Tests for set_fallback_resolver and _get_fallback_label
# ---------------------------------------------------------------------------


@pytest.fixture
def fallback_resolver_fixture():
    """Fixture to save and restore fallback resolver state."""
    from ArWikiCats.legacy_bots.resolvers import country_resolver

    original = country_resolver._fallback_resolver
    yield country_resolver
    # Restore original state after test
    country_resolver._fallback_resolver = original


@pytest.mark.fast
class TestFallbackResolver:
    """Tests for fallback resolver functions."""

    def test_get_fallback_label_without_resolver_returns_empty(self, fallback_resolver_fixture) -> None:
        """Should return empty string when no fallback resolver is set."""
        # Use setter to clear the resolver
        set_fallback_resolver(lambda x: "")
        # Now test with a resolver that returns empty
        result = _get_fallback_label("test")
        assert result == ""

    def test_set_fallback_resolver_sets_callback(self, fallback_resolver_fixture) -> None:
        """Should set the fallback resolver callback."""

        # Set a test resolver
        def test_resolver(category: str) -> str:
            return f"resolved_{category}"

        set_fallback_resolver(test_resolver)
        result = _get_fallback_label("test")
        assert result == "resolved_test"


# ---------------------------------------------------------------------------
# Tests for _validate_separators
# ---------------------------------------------------------------------------


@pytest.mark.fast
class TestValidateSeparators:
    """Tests for the _validate_separators function."""

    def test_returns_true_for_no_separators(self) -> None:
        """Should return True when no separators are present."""
        assert _validate_separators("simple text") is True

    def test_returns_false_for_in_separator(self) -> None:
        """Should return False when 'in' separator is present."""
        assert _validate_separators("events in yemen") is False

    def test_returns_false_for_of_separator(self) -> None:
        """Should return False when 'of' separator is present."""
        assert _validate_separators("history of yemen") is False

    def test_returns_false_for_from_separator(self) -> None:
        """Should return False when 'from' separator is present."""
        assert _validate_separators("people from yemen") is False

    def test_returns_false_for_by_separator(self) -> None:
        """Should return False when 'by' separator is present."""
        assert _validate_separators("songs by artist") is False

    def test_returns_true_for_separator_at_start(self) -> None:
        """Separator at start (not surrounded by spaces) should not match."""
        # "in yemen" - 'in' is at start, not surrounded by spaces on both sides
        assert _validate_separators("inyemen") is True

    def test_returns_false_for_at_separator(self) -> None:
        """Should return False when 'at' separator is present."""
        assert _validate_separators("events at location") is False


# ---------------------------------------------------------------------------
# Tests for check_historical_prefixes
# ---------------------------------------------------------------------------


@pytest.mark.fast
class TestCheckHistoricalPrefixes:
    """Tests for the check_historical_prefixes function."""

    def test_returns_empty_for_no_prefix(self) -> None:
        """Should return empty when no historical prefix is found."""
        result = check_historical_prefixes("random text")
        assert result == ""

    def test_returns_empty_with_separators(self) -> None:
        """Should return empty when input contains separators."""
        result = check_historical_prefixes("defunct national teams in yemen")
        assert result == ""

    def test_handles_defunct_national_prefix(self) -> None:
        """Should handle 'defunct national' prefix."""
        # Will depend on whether remainder can be resolved
        result = check_historical_prefixes("defunct national something")
        assert isinstance(result, str)


# ---------------------------------------------------------------------------
# Tests for Get_country2
# ---------------------------------------------------------------------------


@pytest.mark.fast
class TestGetCountry2:
    """Tests for the Get_country2 function."""

    def test_returns_string(self) -> None:
        """Should return a string."""
        result = Get_country2("test")
        assert isinstance(result, str)

    def test_normalizes_input(self) -> None:
        """Should normalize input to lowercase and strip whitespace."""
        result1 = Get_country2("TEST")
        result2 = Get_country2("test")
        assert result1 == result2

    def test_handles_empty_input(self) -> None:
        """Should handle empty input."""
        result = Get_country2("")
        assert isinstance(result, str)


# ---------------------------------------------------------------------------
# Tests for CountryLabelRetriever class
# ---------------------------------------------------------------------------


@pytest.mark.fast
class TestCountryLabelRetriever:
    """Tests for the CountryLabelRetriever class."""

    def test_init_creates_instance(self) -> None:
        """Should create an instance."""
        retriever = CountryLabelRetriever()
        assert retriever is not None

    def test_get_country_label_returns_string(self) -> None:
        """get_country_label should return a string."""
        retriever = CountryLabelRetriever()
        result = retriever.get_country_label("test")
        assert isinstance(result, str)

    def test_check_basic_lookups_returns_digits(self) -> None:
        """_check_basic_lookups should return digits unchanged."""
        retriever = CountryLabelRetriever()
        result = retriever._check_basic_lookups("12345")
        assert result == "12345"

    def test_check_basic_lookups_returns_string(self) -> None:
        """_check_basic_lookups should return a string."""
        retriever = CountryLabelRetriever()
        result = retriever._check_basic_lookups("test")
        assert isinstance(result, str)

    def test_fetch_country_term_label_returns_string(self) -> None:
        """fetch_country_term_label should return a string."""
        retriever = CountryLabelRetriever()
        result = retriever.fetch_country_term_label("test", "in")
        assert isinstance(result, str)

    def test_fetch_country_term_label_handles_numeric(self) -> None:
        """fetch_country_term_label should return numeric input unchanged."""
        retriever = CountryLabelRetriever()
        result = retriever.fetch_country_term_label("12345", "")
        assert result == "12345"

    def test_fetch_country_term_label_handles_the_prefix(self) -> None:
        """fetch_country_term_label should handle 'the ' prefix."""
        retriever = CountryLabelRetriever()
        result = retriever.fetch_country_term_label("the test", "")
        assert isinstance(result, str)

    def test_handle_type_lab_logic_returns_string(self) -> None:
        """_handle_type_lab_logic should return a string."""
        retriever = CountryLabelRetriever()
        result = retriever._handle_type_lab_logic("test of", "in")
        assert isinstance(result, str)

    def test_handle_type_lab_logic_handles_of_suffix(self) -> None:
        """_handle_type_lab_logic should handle ' of' suffix."""
        retriever = CountryLabelRetriever()
        result = retriever._handle_type_lab_logic("history of", "")
        assert isinstance(result, str)

    def test_handle_type_lab_logic_handles_in_suffix(self) -> None:
        """_handle_type_lab_logic should handle ' in' suffix."""
        retriever = CountryLabelRetriever()
        result = retriever._handle_type_lab_logic("events in", "")
        assert isinstance(result, str)


# ---------------------------------------------------------------------------
# Tests for event2_d2 function
# ---------------------------------------------------------------------------


@pytest.mark.fast
class TestEvent2D2:
    """Tests for the event2_d2 function."""

    def test_returns_string(self) -> None:
        """Should return a string."""
        result = event2_d2("test")
        assert isinstance(result, str)

    def test_returns_empty_for_blocked_words(self) -> None:
        """Should return empty for strings with blocked words."""
        assert event2_d2("events in yemen") == ""
        assert event2_d2("history of yemen") == ""
        assert event2_d2("people from yemen") == ""

    def test_strips_category_prefix(self) -> None:
        """Should strip 'category:' prefix."""
        result1 = event2_d2("category:test")
        result2 = event2_d2("test")
        assert result1 == result2


# ---------------------------------------------------------------------------
# Tests for module-level wrapper functions
# ---------------------------------------------------------------------------


@pytest.mark.fast
class TestModuleFunctions:
    """Tests for module-level wrapper functions."""

    def test_get_country_label_returns_string(self) -> None:
        """get_country_label should return a string."""
        result = get_country_label("test")
        assert isinstance(result, str)

    def test_fetch_country_term_label_returns_string(self) -> None:
        """fetch_country_term_label should return a string."""
        result = fetch_country_term_label("test", "in")
        assert isinstance(result, str)

    def test_fetch_country_term_label_with_lab_type(self) -> None:
        """fetch_country_term_label should handle lab_type parameter."""
        result = fetch_country_term_label("test", "in", lab_type="type_label")
        assert isinstance(result, str)



"""
Main entry point for resolving Arabic Wikipedia category names using multiple specialized resolvers.
This function orchestrates the resolution process by attempting to match a category string
against a series of specific resolvers in a predefined priority order to ensure accuracy
and avoid common linguistic conflicts (e.g., distinguishing between job titles and sports,
or nationalities and country names).

New resolvers for Arabic Wikipedia categories.
"""

from __future__ import annotations

import functools
import logging
from typing import Callable

from ..patterns_resolvers import all_patterns_resolvers
from ..sub_new_resolvers import main_other_resolvers
from ..time_formats import convert_time_to_arabic
from .countries_names_resolvers import main_countries_names_resolvers
from .countries_names_with_sports import main_countries_names_with_sports_resolvers
from .films_resolvers import main_films_resolvers
from .jobs_resolvers import main_jobs_resolvers
from .languages_resolves import resolve_languages_labels_with_time
from .nationalities_resolvers import main_nationalities_resolvers
from .relations_resolver import main_relations_resolvers
from .sports_resolvers import main_sports_resolvers
from .time_and_jobs_resolvers import time_and_jobs_resolvers_main

logger = logging.getLogger(__name__)

# Type alias for resolver functions
ResolverFn = Callable[[str], str]

# Define resolver chain in priority order
# Each tuple contains: (name, resolver_function, priority_notes)
_RESOLVER_CHAIN: list[tuple[str, ResolverFn, str]] = [
    (
        "Time to Arabic",
        convert_time_to_arabic,
        "Highest priority - handles year/century/millennium patterns",
    ),
    (
        "Pattern-based resolvers",
        all_patterns_resolvers,
        "Regex patterns for complex category structures",
    ),
    (
        "Jobs resolvers",
        main_jobs_resolvers,
        "Must be before sports to avoid mis-resolving job titles as sports",
    ),
    (
        "Time + Jobs resolvers",
        time_and_jobs_resolvers_main,
        "Combined time period and job titles",
    ),
    (
        "Sports resolvers",
        main_sports_resolvers,
        "Sports-specific category patterns",
    ),
    (
        "Nationalities resolvers",
        main_nationalities_resolvers,
        "Must be before countries to avoid conflicts (e.g., 'Italy political leader')",
    ),
    (
        "Countries names resolvers",
        main_countries_names_resolvers,
        "Country name patterns",
    ),
    (
        "Films resolvers",
        main_films_resolvers,
        "Film and television categories",
    ),
    (
        "Relations resolvers",
        main_relations_resolvers,
        "Complex relational categories (e.g., dual nationalities)",
    ),
    (
        "Countries with sports resolvers",
        main_countries_names_with_sports_resolvers,
        "Combined country and sport patterns",
    ),
    (
        "Languages resolvers",
        resolve_languages_labels_with_time,
        "Language-related categories with time periods",
    ),
    (
        "Other resolvers",
        main_other_resolvers,
        "Catch-all for remaining patterns",
    ),
]


@functools.lru_cache(maxsize=50000)
def all_new_resolvers(category: str) -> str:
    """Apply all new resolvers to translate a category string.

    The resolution follows a priority-based chain where each resolver is tried
    in order until one returns a non-empty result. The order is critical for
    correctness - see _RESOLVER_CHAIN for priority notes.

    Args:
        category (str): The category string to resolve.

    Returns:
        str: The resolved category label, or empty string if not resolved.
    """
    logger.info(f"<<purple>> : {category}")

    for name, resolver, _ in _RESOLVER_CHAIN:
        result = resolver(category)
        if result:
            logger.info(f"<<purple>> : {category} => {result} via {name}")
            return result

    logger.debug(f"<<purple>> : {category} => no match")
    return ""
